easypackages::packages(c("tidyverse", 'sf', 'raster','sp','dplyr','spatialEco',
                         'exactextractr','tibble', 'here', "readr", "margrittr","tydr",
                         "readxl", "foreign", "data.table", "spData","spDataLarge", "purrr", 
                         "rgdal", "lwgeom", "matlib"
))

# Loading data  --------------------------------------------------------------------

# spatial data - transforming - subsetting --------------------------------
# Gaul2015
shape_gaul=read_sf(here("Input_data", "g2015_2014_1.shp")) 
gaul_grouping = read_excel("Input_data/g2015_2014/GAUL2015_AdditionalAttributes/GAUL2015_AdditioinalAttributes_wrkbk.xlsx", 
                           sheet = "Group_M49")
gaul_mapping = read_excel("Input_data/g2015_2014/GAUL2015_AdditionalAttributes/GAUL2015_AdditioinalAttributes_wrkbk.xlsx", 
                          sheet = "SALB_2015")
gaul_official_nams = read_excel("Input_data/g2015_2014/GAUL2015_AdditionalAttributes/GAUL2015_AdditioinalAttributes_wrkbk.xlsx", 
                                sheet = "Official_Nms")

# Country mapping ---------------------------------------------------------
# FAOstat country
FAOSTAT_cntr <- read_csv(here("Input_data", "Mappings", "FAOSTAT_data_4-22-2021_all_FAOSTAT_coutnries.csv")) %>% 
  dplyr::select(-c("Start Year", "End Year"))
# CIFOS countries 
# Loading the data with SPAM, CIFOS, GAUL2015, FAO countries 
dat_map_SPAM_GAUL_CIFOS_FAO = read.csv(here("Input_data", "Mappings", "dat_map_SPAM_GAUL_CIFOS_FAO.csv")) %>%  as_tibble()
dat_map_SPAM_GAUL_CIFOS_FAO_full = dat_map_SPAM_GAUL_CIFOS_FAO %>% 
  dplyr::select(-M49_Code, -iso2_code_FAO, -iso3_code_FAO) %>% left_join(., FAOSTAT_cntr, by = c("name_cntr_FAO" = "Country")) #needs some more checking > NAs in last col
# dat_map_SPAM_GAUL_CIFOS_FAO = dat_map_SPAM_GAUL_CIFOS %>%  full_join(., FAOSTAT_cntr, c("name_cntr_GAUL2015" ="Country")) 
# write_csv(dat_map_SPAM_GAUL_CIFOS_FAO, here("Input_data", "Mappings", "dat_map_SPAM_GAUL_CIFOS_FAO.csv"))

# Distinct at SPAM 2010 
dat_map_SPAM_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(iso3_SPAM), .keep_all = T)
# Distinct at CIFOS 
dat_map_CIFOS_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(name_cntr_CIFOS2021), .keep_all = T) #correct
# Distinct at GAUL2015 
dat_map_GAUL2015_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(name_cntr_GAUL2015), .keep_all = T) #correct

# EU-28 susbett 
dat_map_GAUL2015_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(name_cntr_GAUL2015), .keep_all = T) #correct

# SUbsetting crop variables for EU28
cntr_FAO_EU28 = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% filter(., iso3_SPAM  %in% EU_iso3) 


# SUbsetting countries and crop variables for EU28
EU_iso3 = c("AUT","BEL", "BGR", "HRV", "CZE", "DNK", "EST","FIN", "FRA", "DEU", "GRC", "HUN", "IRL", "ITA","LVA", 
            "LTU", "LUX", "MLT", "NLD", "POL", "PRT","ROU", "SVK","SVN", "ESP", "SWE", "GBR", "CYP")
str(EU_iso3)
cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28 = dat_map_SPAM_GAUL_CIFOS_FAO %>% filter(., iso3_SPAM  %in% EU_iso3) 
# write_csv(cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28, here("Input_data", "cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28.csv"))


# FAOSTAT
crops_FAO_global = read_csv("Input_data/FAOSTAT_data_4-20-2021_crops_vars_global_2009_2011.csv")
nutrients_FAO_global = read_csv("Input_data/FAOSTAT_data_4-20-2021_Nutrients_agriuse_NP.csv")

# SUbsetting crop variables for EU28
crops_FAO_EU28 = crops_FAO_global %>% filter(., Area %in% cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28$name_cntr_FAO) %>% 
  left_join(.,cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28, by = c("Area"="name_cntr_FAO"))#checked EU28
# distinct_at(crops_FAO_EU28, vars(Area))

# SUbsetting fertilization variables for EU28
fertilizer_FAO_EU28 = nutrients_FAO_global %>% filter(., Area %in% cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28$name_cntr_FAO) %>%  #checked EU28
  left_join(.,cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28, by = c("Area"="name_cntr_FAO"))
# distinct_at(fertilizer_FAO_EU28, vars(Area))

# SPAM crop mapping
SPAM2010_CropList = read_excel("Input_data/Mappings/SPAM2010_CropList.xlsx", 
                               sheet = "crop_map_distinct") %>% 
  mutate_at(c("short_spam2010"), funs(recode(., 'oveg'='GreenVeg',
                                             'oveg'='RestVeg',
                                             'rveg'='RedYelVeg',
                                             'tnut'='tnuts')))
# Croplist with surogate species and Nfix
SPAM_Nfix= read_excel("Input_data/Mappings/SPAM2010_CropList.xlsx", 
                          sheet = "Legumes") 

# Merging the N fix and croplist
SPAM2010_CropList = SPAM2010_CropList %>%  left_join(., SPAM_Nfix, by = c("short_spam2010" = "crops_spam"))

# NP content
crops_NP = read_csv(here("Input_data", "NP_content_agg.csv")) %>% distinct_at(vars(short_spam2010), .keep_all = T) %>%  #Distinct crops 
  drop_na(short_spam2010) %>% 
  mutate_at(c("short_spam2010"), funs(recode(., 'dveg'='GreenVeg',
                                             'oveg'='RestVeg',
                                             'rveg'='RedYelVeg',
                                             'tnut'='tnuts')))

# Loading parameters from LUn et al 2018 dataset. I calculated the ratios for P between grassland and cropland for manure and art fert. And the fraction of losses by runoff.
Lun2018_P_frac <- read_csv("Input_data/Lun_P_budget.csv", 
                           col_types = cols( 
                                            c_ArtFert_rate_kgha = col_double(), 
                                            c_manure_rate_kgha = col_double(), 
                                            `c_humanManure_kg/ha` = col_double(), 
                                            c_cropres_kgha = col_double(), c_deposition_kgha = col_double(), 
                                            c_total_input_kgha = col_double(), 
                                            c_runoff_kgha = col_double(), g_deposition_kghA = col_double(), 
                                            g_manure_kgha = col_double(), g_fert_kgha = col_double(), 
                                            g_output_kgha = col_double(), g_runoff_kgha = col_double(), 
                                            ratio_art_g2c = col_double(), ratio_m_g2c = col_double(), 
                                            c_frac_runoff2totinput = col_double(), 
                                            g_frac_runoff2totinput = col_double())) 



Lun2018_P_frac_cntr_ful = Lun2018_P_frac %>%  mutate(Country = recode(Country,'Czech Republic' =  "Czechia")) %>% 
  mutate(Country = recode(Country,"United Kingdom" = "United Kingdom of Great Britain and Northern Ireland")) %>% 
  left_join(., dat_map_GAUL2015_dist, by=c("Country" = "name_cntr_FAO")) %>% 
  filter(., iso3_SPAM  %in% cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28$iso3_SPAM)
  # dplyr::select(iso3_SPAM, name_cntr_CIFOS2021, c_ArtFert_rate_kgha:g_frac_runoff2totinput )

#I replaced the missing countries Malta and Cyprus with Spain and Greece values, respectively in excel (therefore export and import)
# write.csv(Lun2018_P_frac_cntr_ful, here("Input_data", "Lun2018_P_frac_cntr_ful.csv")) 
Lun2018_P_frac_cntr_ful_EU28 = read_csv(here("Input_data", "Lun2018_P_frac_cntr_ful.csv")) 

# Loading N manure sheet from FAOSTAT global 
Nmanure <- read_csv("Input_data/FAOSTAT_data_5-11-2021_Nmanuresoil.csv") %>% as_tibble()

# Loading grass 2 crop 2 fodder fractions from FAO 2006 
Nfrac_Fertilizer <- read_csv("Input_data/cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28_Fertilizer.csv", 
                                                         col_types = cols(Note = col_skip()))

# getting fraction of manure
# N manure values -  Creating three year average and cleaning variables
Nmanure2010global = Nmanure %>%
  dplyr::select(Area, "Area Code", Element, Year, Unit, Value) %>% 
  group_by(Area, Element) %>%
  mutate(Value = mean(Value)) %>%  #creating three year average
  filter(Year==2010)

# EU28 subset and cacluating the loss shares
NmanureEU28 = Nmanure2010global %>% 
  filter(., Area %in% cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28$name_cntr_FAO) %>% 
  pivot_wider(names_from = Element, values_from = Value) %>%
  mutate(Nvol_frac_man = `Manure applied to soils that volatilises (N content)`/`Manure applied to soils (N content)`,
         Nleach_frac_man = `Manure applied to soils that leaches (N content)`/`Manure applied to soils (N content)`,
         Nlosses_soil_man = (`Manure applied to soils that leaches (N content)`+`Manure applied to soils that volatilises (N content)` )/ `Manure applied to soils (N content)`)
  
Fertilizer_fraction_N =  read_csv("Input_data/cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28_Fertilizer.csv", 
                                  col_types = cols(Note = col_skip())) %>% 
  dplyr::select(iso3_SPAM, ratio_fert_g2c:tot_frac_noncrop)
  
  
# Crops with peat/npeat aggregated on national level and on intensity level
SPAM_EU28_dat = read_csv(here("Input_data", "DataValidationFinal.csv")) %>% dplyr::select(-c(X10)) %>% 
  drop_na(country_cifos) %>% left_join(., cntr_FAO_SPAM_GAUL_CIFOS_FAO_EU28, by = c("iso3" = "iso3_SPAM"))%>%  #checked EU28
  left_join(., Fertilizer_fraction_N, by = c("iso3"="iso3_SPAM")) %>% 
  mutate_at(c("crops_cifos"), funs(recode(., 'String beans'='Sugar beets')))
  

  # distinct_at(SPAM_EU28_dat, vars(iso3))


# NP and DM percentage per crop 
crops_NP_map = crops_NP %>% left_join(., SPAM2010_CropList, by="short_spam2010") %>% 
  dplyr::select(-contains(".x")) %>%
  rename_with(~str_remove(., "\\.y")) %>% #use regex 
  drop_na(any_of("code_fao")) %>%
  dplyr::select(short_spam2010, name_fao, cifos_crops, code_spam2010, code_fao, name_fao,  `Dmcontent%`, Ntotal, Ptotal, legumes, NifxCoef_tNfix_per_tDM) %>% 
  rename(DM_perc =`Dmcontent%`)

write_csv(crops_NP_map, here("Input_data", "crops_NP.csv"))
# Do the proper aggregation for groups 
# --> DONE in excel

# Calculate total NP content per crop  - NP content DM * production
# Calculating the crop requirements (country, crop, all intensity levels combined (A))
NP_content = crops_NP_map %>% 
  right_join(., SPAM_EU28_dat, by=c("short_spam2010"="crops_spam")) %>%
  mutate(Nutr_req_harv_N = (Ntotal/100)*(DM_perc/100)*Production_mt, #NP removal from production
         Nutr_req_harv_P = (Ptotal/100)*(DM_perc/100)*Production_mt) %>% 
  mutate(N_removal_kgha = Nutr_req_harv_N*1000/HarvestedArea_ha, #NP removal (kg/ha) from yields (transforming tonnes to kg)
         P_removal_kgha = Nutr_req_harv_P*1000/HarvestedArea_ha) %>% 
  mutate(Nfixed_t = case_when(legumes == "y" ~ (DM_perc/100)*Production_mt*NifxCoef_tNfix_per_tDM, TRUE ~ 0), #Caluclating the total Nfixed from crop production
         Nfixed_kgha = case_when(legumes == "y" ~ (DM_perc/100)*Production_mt*1000*NifxCoef_tNfix_per_tDM/HarvestedArea_ha, TRUE ~ 0))


# Ratio of crops per defined zones (here per crop and country) ------------
NP_content_ratio = NP_content %>%  
  pivot_longer(cols= "Nutr_req_harv_N":"Nutr_req_harv_P", names_to = "nutr_req_production") %>%
  # pivot_longer(cols= "N_removal_kgha":"P_removal_kgha", names_to = "nutr_req_yield", names_repair = "unique")
  mutate_at(vars(value), ~replace(., is.nan(.), 0))%>% 
  # mutate(value_cor = case_when(legumes == "y" ~ value-Nfixed_t,
  #                              TRUE ~ value),
  #        value_cor = case_when(value_cor < 0 ~ 0, # all the negative values are set to 0 (negative meaning that the amount of N fixed is larger than the amount of N in the crop)
  #                              TRUE ~ value_cor)) %>% 
  group_by(iso3, nutr_req_production) %>% #no distinction between peat/non-peat in terms of fertilization 
  mutate(NP_content_ratio = (value/sum(value))) %>%
  # mutate(NP_content_ratio_yld = value...13/sum(value...13)) %>%
  mutate(label = case_when(stringi::stri_detect_fixed(nutr_req_production, "_N") ~ "N",
                           stringi::stri_detect_fixed(nutr_req_production, "_P")  ~ "P"))
# 
# # Nfix correction
# NP_content_ratioNP_content_ratio = NP_content %>%  
#   pivot_longer(cols= "Nutr_req_harv_N":"Nutr_req_harv_P", names_to = "nutr_req_production") %>%
#   # pivot_longer(cols= "N_removal_kgha":"P_removal_kgha", names_to = "nutr_req_yield", names_repair = "unique")
#   mutate_at(vars(value), ~replace(., is.nan(.), 0))%>% 
#   mutate(value_cor = case_when(legumes == "y" ~ value-Nfixed_t,
#                                TRUE ~ value),
#          value_cor = case_when(value_cor < 0 ~ 0, # all the negative values are set to 0 (negative meaning that the amount of N fixed is larger than the amount of N in the crop)
#                                TRUE ~ value_cor)) %>% 
#   group_by(iso3, nutr_req_production) %>% #no distinction between peat/non-peat in terms of fertilization 
#   mutate(NP_content_ratio = (value_cor/sum(value_cor))) %>%
#   # mutate(NP_content_ratio_yld = value...13/sum(value...13)) %>%
#   mutate(label = case_when(stringi::stri_detect_fixed(nutr_req_production, "_N") ~ "N",
#                            stringi::stri_detect_fixed(nutr_req_production, "_P")  ~ "P"))


# eval - all correct (28.04.2021)
# val=NP_content_ratio %>% group_by(iso3, nutr_req) %>% 
#   summarize(val = sum(perc))

# # FAO NP consumption data: Creating three year average and cleaning variables
# avg_yr_all_EU28 = fertilizer_FAO_EU28 %>%
#   group_by(Area, Element, Domain, Item) %>%
#   mutate(Value = mean(Value)) %>%  #creating three year average
#   filter(Year==2010) %>%
#   dplyr::select(-c(`Domain Code`, `Year Code`)) %>% 
#     mutate(Value = case_when(Item == "Nutrient phosphate P2O5 (total)" ~ Value/2.29, #converting P2O5 to P > conversion facrotr 2.29 https://www.researchgate.net/post/How-to-calculate-phosphorous-from-P2O5-which-has-been-recommended-at-the-standard-dose-of-45-kg-ha, https://plants.usda.gov/npk/fertilizer_equivalents_def.html 
#                              Item == "Nutrient nitrogen N (total)" ~ Value),
#            Item = recode(Item,'Nutrient phosphate P2O5 (total)' =  "Nutrient phosphate P (total)"))
#   

nutrients_FAO_2010_EU28 = fertilizer_FAO_EU28 %>%
  group_by(Area, Element, Domain, Item) %>%
  mutate(Value = mean(Value)) %>%  #creating three year average
  filter(Year==2010) %>%
  # dplyr::select(-c(`Domain Code`, `Year Code`)) %>% 
  mutate(Value = case_when(Item == "Nutrient phosphate P2O5 (total)" ~ Value/2.29, #converting P2O5 to P > conversion facrotr 2.29 https://www.researchgate.net/post/How-to-calculate-phosphorous-from-P2O5-which-has-been-recommended-at-the-standard-dose-of-45-kg-ha, https://plants.usda.gov/npk/fertilizer_equivalents_def.html 
                           Item == "Nutrient nitrogen N (total)" ~ Value),
                                      Item = recode(Item,'Nutrient phosphate P2O5 (total)' =  "Nutrient phosphate P (total)")) %>% 
  dplyr::select(Area, iso3_code_FAO, `Area Code`, Domain, Item, `Item Code`, Year, Value)

# Creating cifos join df
cifos_crop = SPAM_EU28_dat %>% dplyr::select(crops_cifos, crops_spam) %>% distinct_at(vars(crops_spam), .keep_all = T)

# Creating join of loss and grassland fractions
NP_loss_gras_fod_fractions = NmanureEU28 %>%
 left_join(., cntr_FAO_EU28, by=c("Area Code"="Country Code"))%>%
  dplyr::select(iso3_SPAM, `Manure applied to soils (N content)`:Nlosses_soil_man) %>% 
  left_join(.,Lun2018_P_frac_cntr_ful_EU28, by = "iso3_SPAM") 


# Adding NP labels, multiplying FAO consumption with crop share ratios and Identify the gap between FAO and Requirements
gapFAO_SPAM = nutrients_FAO_2010_EU28 %>% 
  mutate(label = case_when(stringi::stri_detect_fixed(Item, "nitrogen") ~ "N",
                           stringi::stri_detect_fixed(Item, "phosphate")  ~ "P")) %>% 
  left_join(., NP_loss_gras_fod_fractions, by="Area") %>% 
  right_join(.,NP_content_ratio, by=c("iso3_code_FAO"="iso3", "label"="label")) %>%
  rename("TotFertConsum" = "Value", 
         "Crop_req_tot" = "value_cor") %>% 
    # Calculating the amount of Manure and Artfert available for crop fertilization: i.e. FertMan =  tot_man - losses - manfod - mangrass
  mutate(Nman_foodcrop  = case_when(label == "N" ~ `Manure applied to soils (N content)`*NP_content_ratio*(1-Nlosses_soil_man)*(1-ratio_m_g2c_1)*(1-(0.24+0.212))), #IPCC fractions for volitalisation org and leaching losses wet at last position. Ratio manure to grassland is from Lun et al for P.
         Nfert_foodcrop = case_when(label == "N" ~ TotFertConsum*NP_content_ratio*(1-ratio_fert_fod2c)*(1-ratio_fert_g2c)*(1-(0.24+0.11))),#IPCC fractions for volitalisation ARTifical and leaching losses wet at last position
         Pman_foodcrop  = case_when(label == "P" ~ ((c_manure_rate_kgha)*`Total Area`)* NP_content_ratio*(1-ratio_m_g2c_1)*(1-0.125)),
         Pfert_foodcrop  = case_when(label == "P" ~ `TotFertConsum`*NP_content_ratio*(1-ratio_art_g2c_1)*(1-0.125))) %>%
  # dplyr::select(country_cifos, crops_cifos, peat, label, Nman_foodcrop:Pfert_foodcrop, Crop_req_tot, NP_content_ratio) %>% 
  # Calculating the gap between what is there and the crop requirement
  mutate(nutr_gap = case_when(Crop_req_tot > 0 & label == "N" ~ ((Nman_foodcrop+Nfert_foodcrop)-Crop_req_tot), 
                              TRUE ~ 0)) %>%
  mutate(nutr_gap = case_when(Crop_req_tot > 0 & label == "P" ~ ((Pman_foodcrop+Pfert_foodcrop)-Crop_req_tot),  
                                TRUE ~ 0)) %>%  
  mutate(fert_rate = case_when(label == "N" ~ nutr_gap*1000/HarvestedArea_ha,
                               label == "P" ~ nutr_gap*1000/HarvestedArea_ha)) %>% 
  mutate_at(vars(fert_rate), ~replace(., is.nan(.), 0)) %>% 
  ungroup() %>%
  # left_join(., cifos_crop, by = c("short_spam2010"="crops_spam")) #%>% 
  dplyr::select(country_cifos, crops_cifos, peat, label, fert_rate) %>% 
  rename(nutrient = label,
         fert_rate_kgha = fert_rate)

# write_csv(gapFAO_SPAM, here("Input_data", "FertilizationRates_chng.csv"))
          


# Simple loss approach -----------------------------------------------------
Fert_rate_simple = nutrients_FAO_2010_EU28 %>% 
  mutate(label = case_when(stringi::stri_detect_fixed(Item, "nitrogen") ~ "N",
                           stringi::stri_detect_fixed(Item, "phosphate")  ~ "P")) %>% 
  left_join(., NP_loss_gras_fod_fractions, by="Area") %>% 
  right_join(.,NP_content_ratio, by=c("iso3_code_FAO"="iso3", "label"="label")) %>%
  rename("TotFertConsum" = "Value", 
         "Crop_req_tot" = "value") %>% 
  mutate(Nfert_req_kgha = N_removal_kgha + N_removal_kgha * (0.24+0.212),
         Pfert_req_kgha = P_removal_kgha + P_removal_kgha*0.125) %>% 
  dplyr::select(country_cifos, crops_cifos, peat, label, Nfert_req_kgha, Pfert_req_kgha)
  



# Old ---------------------------------------------------------------------


          # # gapFAO_SPAM %>%
          # #   ggplot(aes(y=fert_rate))+
          # #   geom_histogram(bins = 5)
          # 
          # # Calculate the ratio of each crop per Zone, country based on requirements (Allocation factor based) > Scaling
          # # Ratio from NP values of the crops in EU27
          # NP_ratio = NP_content_ratio %>% dplyr::select(iso3, peat, label, short_spam2010, NP_content_ratio)
          # 
          # fert_rates_alloc = gapFAO_SPAM %>% 
          #   mutate(FAO_fert_alloc = NP_content_ratio*Value)
          # 
          # 
          # 
          # 
          # # allocate the amount of NP fertilizer (GAP between requirement and FAO) to the crops based on the allocation factor based on point 2
          # 
          # 
          # 
          # 
          # 
          # 
          # # Creating three year average and cleaning variables
          # avg_yr_all_EU27 = crops_nutrients_EU27 %>%
          #   group_by(Area, Element, Domain, Item) %>%
          #   mutate(av_value = mean(Value)) %>%  #creating three year average
          #   filter(Year==2010) %>%
          #   dplyr::select(-c(`Domain Code`, Value, Flag, `Flag Description`)) %>%
          #   rename(Value = av_value)
          # 
          # avg_yr_crops_EU27 = crops_EU27 %>% 
          #   group_by(Area, Element, Domain, Item) %>% 
          #   mutate(av_value = mean(Value)) %>%  #creating three year average 
          #   filter(Year==2010) %>% 
          #   dplyr::select(-c(`Domain Code`, Value, Flag, `Flag Description`)) %>% 
          #   rename(Value = av_value)
          # 
          # avg_yr_nutrients_EU27 = nutrients_EU27 %>% 
          #   group_by(Area, Element, Domain, Item) %>% 
          #   mutate(av_value = mean(Value)) %>%  #creating three year average 
          #   filter(Year==2010) %>% 
          #   dplyr::select(-c(`Domain Code`, Value, Flag, `Flag Description`)) %>% 
          #   rename(Value = av_value) %>% 
          #   dplyr::select(Area, Item, `Item Code`, Unit, Value)
          # 
          # 
          # 
          # # proportion of production and harvested area per country and SPAM crop -------------------
          # Prop_avg_yr_crops_EU27 = avg_yr_crops_EU27 %>% 
          #   dplyr::select(-c(Unit, `Element` )) %>% 
          #   spread(Element, Value) %>% 
          #   drop_na() %>% 
          #   left_join(., SPAM2010_CropList, by=c(`Item Code`="code_fao")) %>%
          #   group_by(Area, short_spam2010) %>%  
          #   mutate(harv_area = sum(`Area harvested`),
          #          production = sum(Production)) %>% 
          #   mutate(Production = Production*1000) %>% #convert from t, ones to kg, harvested area is in ha already
          #   group_by(Area) %>% 
          #   distinct_at(vars(short_spam2010), .keep_all =T) %>% 
          #   mutate_at(vars(harv_area,Production),
          #             .funs = list(prop = ~ (.)/sum(.)))
          # # write_csv(Prop_avg_yr_crops_EU27, here("input_data", "check6.csv"))
          # 
          # # Here we just summarize by variables to keep it cleaner
          # Prop_avg_yr_crops_EU27 = Prop_avg_yr_crops_EU27 %>% 
          #   group_by(Area, short_spam2010) %>% 
          #   summarise(Area, Item, `harv_area_prop`, Production_prop, `harv_area`, Production)
          # 
          # #Check approach: Testing if the two proportion of harv and prod are correlated with each other. 
          # # They are strongly
          # gg_prop = Prop_avg_yr_crops_EU27 %>% 
          #   ggplot(., aes(x=`harv_area_prop`, y=Production_prop))+
          #   geom_point()+
          #   geom_smooth()+
          #   geom_abline()
          # 
          # # Calulating the proportion of fertilizer per crop and country ------------
          # # Join crop and nutrient datasets together 
          # nut_crop_EU27 = Prop_avg_yr_crops_EU27 %>% 
          #   left_join(., avg_yr_nutrients_EU27, by=c("Area")) %>% 
          #   dplyr::select(-c(Domain, Unit, Item.y)) %>% 
          #   spread(`Item Code` ,Value) %>% 
          #   rename(Ntot_ton = `3102`,
          #          Ptot_ton = `3103`) %>% 
          #   group_by(short_spam2010, Area) %>% 
          #   mutate_at(vars(Ntot_ton:Ptot_ton),
          #             .funs = list(fert_crop_prod_prop = ~ (.)* Production_prop)) %>% 
          #   mutate_at(vars(Ntot_ton:Ptot_ton),
          #             .funs = list(fert_crop_harv_prop = ~ (.)* harv_area_prop))
          # 
          # 
          # 
          # # Calulating the final fertilization rate per crop and country ------------
          # # Approach: multiply  the total amount of fertilizer with the fraction and then divide it by the type per alocated harvested land and crop
          # 
          # Nfert_rates_SPAMcrop_country = nut_crop_EU27 %>% 
          #   rowwise() %>% 
          #   mutate(Nfert_prod_kg_ha = Ntot_ton_fert_crop_prod_prop*1000/harv_area, #convertin the tonnes of fert into kg by *1000
          #          Nfert_harv_kg_ha = Ntot_ton_fert_crop_harv_prop*1000/harv_area,
          #          Pfert_prod_kg_ha = Ptot_ton_fert_crop_prod_prop*1000/harv_area,
          #          Pfert_harv_kg_ha = Ptot_ton_fert_crop_harv_prop*1000/harv_area) 
          # 
          # write_csv(Nfert_rates_SPAMcrop_country, here("Input_data", "Nfert_rates_SPAMcrop_country_mean_EU27.csv"))
          # # Check this output > do fertilziation rates make sense?
          # 
          # 
          # # PLotting results  -------------------------------------------------------
          # # Barplot
          # 
          # # Comparing the countries for different NP fertilization
          # gg_fert=Nfert_rates_SPAMcrop_country %>% 
          #   pivot_longer(cols="Nfert_prod_kg_ha":"Pfert_harv_kg_ha", 
          #                names_to = "FertilizerRateKgHa")
          # 
          # g1= ggplot(gg_fert, aes(x=Area, y=value, fill = FertilizerRateKgHa))+
          #   # geom_bar(stat="identity", position= "dodge", alpha=0.7, show.legend = F) +
          #   geom_bar(position = "dodge", stat = "summary", fun = "mean", alpha=0.7, show.legend = T)+
          #   # geom_errorbar(aes(x=veg_type.x, ymin=mean-sd , ymax=mean+sd), width=0.4, colour="black", alpha=0.9, size=1.3)+
          #   # facet_wrap(~Item.x, scales = "free_y")+
          #   theme(axis.text.x=element_text(angle = -90, hjust = 0))
          # 
          # # Comparing crops_EU27
          # g2 = ggplot(gg_fert,aes(x=short_spam2010, y=value, fill = FertilizerRateKgHa))+
          #   geom_bar(stat="identity", position= "dodge", alpha=0.7, show.legend = F) +
          #   geom_bar(position = "dodge", stat = "summary", fun = "mean", alpha=0.7, show.legend = T)+
          #   # geom_errorbar(aes(x=veg_type.x, ymin=mean-sd , ymax=mean+sd), width=0.4, colour="black", alpha=0.9, size=1.3)+
          #   # facet_wrap(~Item.x, scales = "free_y")+
          #   theme(axis.text.x=element_text(angle = -90, hjust = 0))+
          #   geom_hline(yintercept=300, linetype="dashed", 
          #              color = "red", size=2)
          # 
          # 
          # # Crops comparison
          # p <- ggplot(gg_fert, aes(x=FertilizerRateKgHa, y=value)) + 
          #   geom_violin(trim=T)+ 
          #   stat_summary(fun.data="mean_sdl", mult=1, 
          #                geom="crossbar", width=0.2 )+ 
          #   stat_summary(fun.data=mean_sdl, mult=1, 
          #                geom="pointrange", color="red")
          # 
          # 
          