easypackages::packages(c("tidyverse", 'sf', 'raster','sp','dplyr','spatialEco',
                         'exactextractr','tibble', 'here', "readr", "margrittr","tydr",
                         "readxl", "foreign", "data.table", "spData","spDataLarge", "purrr", "rgdal", "lwgeom"
))


# COUNTRIES ---------------------------------------------------------------


# Load GAUL2015 -----------------------------------------------------------
shape_gaul=read_sf(here::here("Input_data", "g2015_2014_1.shp")) 
shape_gaul_unique$ADM0_ADM1 = paste(shape_gaul_unique$ADM0_CODE, shape_gaul_unique$ADM1_CODE, sep= "_")
shape_gaul_short_tbl = shape_gaul %>%  as_tibble() %>% dplyr::select(-geometry)

# write_csv(shape_gaul_short_tbl, here("Input_data", "shape_gaul_short.csv"))

gaul_grouping = read_excel(here("Input_data","g2015_2014","GAUL2015_AdditionalAttributes","GAUL2015_AdditioinalAttributes_wrkbk.xlsx"), 
                           sheet = "Group_M49")
gaul_mapping = read_excel(here("Input_data","g2015_2014","GAUL2015_AdditionalAttributes","GAUL2015_AdditioinalAttributes_wrkbk.xlsx"), 
                          sheet = "SALB_2015")
gaul_official_nams = read_excel(here("Input_data","g2015_2014","GAUL2015_AdditionalAttributes","GAUL2015_AdditioinalAttributes_wrkbk.xlsx"), 
                                sheet = "Official_Nms")

# EU28 --------------------------------------------------------------------
EU_iso3 = c("AUT","BEL", "BGR", "HRV", "CZE", "DNK", "EST","FIN", "FRA", "DEU", "GRC", "HUN", "IRL", "ITA","LVA", 
            "LTU", "LUX", "MLT", "NLD", "POL", "PRT","ROU", "SVK","SVN", "ESP", "SWE", "GBR", "CYP")

EU_cntr_Cifos = c("Austria","Belgium","Bulgaria","Croatia","Cyprus", "Czechia","Denmark",
                  "Estonia","Finland","France","Germany","Greece","Hungary","Ireland",
                  "Italy","Latvia","Lithuania","Luxembourg","Malta","Netherlands","Poland",
                  "Portugal","Romania","Slovakia","Slovenia","Spain","Sweden",'United Kingdom')

# Exporting countries from different file sources 
# SPAM2010
dat_TA_pr <- read_csv(here("Input_data", "spam2010V2r0_global_P_TA.csv")) # (LATIN2 encoding is used for proper display of nordic and slavic names 
dat_SPAM_adm0 = dat_TA_pr %>% dplyr::select(iso3, name_cntr) %>% distinct_at(vars(iso3, name_cntr))

write_csv(dat_SPAM_adm0, here("Input_data", "Mappings", "dat_SPAM_adm0.csv"))

# GAUL2015
dat_GAUL2016_adm0 = shape_gaul_short_tbl %>% dplyr::select(ADM0_CODE, ADM0_NAME) %>% 
  distinct_at(vars(ADM0_CODE, ADM0_NAME))
write_csv(dat_GAUL2016_adm0, here("Input_data", "Mappings", "dat_GAUL2016_adm0.csv"))

# FAOstat country
FAOSTAT_cntr <- read_csv(here("Input_data", "Mappings", "FAOSTAT_data_4-22-2021_all_FAOSTAT_coutnries.csv")) %>% 
  dplyr::select(-c("Start Year", "End Year"))

# CIFOS countries 
# Loading the data with SPAM, CIFOS, GAUL2015, FAO countries 
dat_map_SPAM_GAUL_CIFOS_FAO = read.csv(here("Input_data", "Mappings", "dat_map_SPAM_GAUL_CIFOS_FAO.csv")) %>%  as_tibble()
dat_map_SPAM_GAUL_CIFOS_FAO_full = dat_map_SPAM_GAUL_CIFOS_FAO %>% 
  dplyr::select(-M49_Code, -iso2_code_FAO, -iso3_code_FAO) %>% left_join(., FAOSTAT_cntr, by = c("name_cntr_FAO" = "Country")) #needs some more checking > NAs in last col
# dat_map_SPAM_GAUL_CIFOS_FAO = dat_map_SPAM_GAUL_CIFOS %>%  full_join(., FAOSTAT_cntr, c("name_cntr_GAUL2015" ="Country")) 
# write_csv(dat_map_SPAM_GAUL_CIFOS_FAO, here("Input_data", "Mappings", "dat_map_SPAM_GAUL_CIFOS_FAO.csv"))

# Distinct at SPAM 2010 
dat_map_SPAM_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(iso3_SPAM), .keep_all = T)
# Distinct at CIFOS 
dat_map_CIFOS_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(me_cntr_CIFOS2021), .keep_all = T) #correct
# Distinct at GAUL2015 
dat_map_GAUL2015_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(me_cntr_GAUL2015), .keep_all = T) #correct

# EU-28 susbett 
dat_map_GAUL2015_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(me_cntr_GAUL2015), .keep_all = T) #correct

# SUbsetting crop variables for EU28
crops_FAO_EU28 = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% filter(., iso3_SPAM  %in% EU_iso3) 

# Crops  ------------------------------------------------------------------
# SPAM crop mapping with Cifos, FAO > DISTINCT > Choice of surgate species for crop groups based on production volume globally
CropList_SPAM_FAO_CIFOS_distinct = read_excel("Input_data/Mappings/SPAM2010_CropList.xlsx", 
                               sheet = "crop_map_distinct")

CropList_SPAM_FAO_CIFOS_disag = read_excel("Input_data/Mappings/SPAM2010_CropList.xlsx", 
                                     sheet = "SPAM2010_FAO_agg_pattern")

