easypackages::packages(c("tidyverse", 'sf', 'raster','sp','dplyr','spatialEco',
                         'exactextractr','tibble', 'here', "readr", "margrittr","tydr",
                         "readxl", "foreign", "data.table", "spData","spDataLarge", "purrr", "rgdal", "lwgeom", "foreign"))



# Functions  --------------------------------------------------------------
Fun_percentage_peat = function(dat_peat_area){
  dat_peat_area %>% 
    pivot_wider(names_from = gridcode, 
                values_from = AREA) %>% 
    rename(peat = `2`,
           non_peat = `1`) %>% 
    replace_na(list(non_peat = 0)) %>% 
    replace_na(list(peat = 0)) %>%
    dplyr::select(-c(Shape_Area, PERCENTAGE)) %>% 
    group_by(ADM0_CODE) %>%
    summarise(across(c("non_peat", "peat"), list(sum))) %>% 
    mutate_at(vars(non_peat_1:peat_1),
              .funs = list(perc = ~ (.)/(non_peat_1+peat_1)*100)) %>% 
  mutate(frac_nopeat = non_peat_1_perc/100) %>% 
  mutate(frac_peat = peat_1_perc/100) %>% 
  dplyr::select(-c(non_peat_1:peat_1_perc )) %>% 
  pivot_longer(cols = contains("peat"), names_to = "peat", values_to = "peat_frac") %>% 
  mutate_at(c("peat"), 
            funs(recode(.,'peat_1_perc' = 'peat',
                        "non_peat_1_perc" = "nopeat"))) %>% 
    left_join(., dat_map_CIFOS_dist, by = c("ADM0_CODE"="ADM0_CODE_GAUL")) %>% 
    filter(iso3_SPAM  %in% EU_iso3)
    # mutate_at(c("ADM0_NAME"), 
    #           funs(recode(.,'U.K. of Great Britain and Northern Ireland'  = 'United Kingdom of Great Britain and Northern Ireland',
    #                       "Czech Republic" = "Czechia"))) 
}

FunProjectionRAST = function(geofile){
  proj = "+proj=longlat +datum=WGS84 +no_defs +units=m" # taken from raster file below
  projectRaster(geofile, crs = proj)
  return(geofile)
}

# Cleaning, subsetting and transforming some numbers of the peat dataset 
FUN_peat_past_crop = function(dat){
  dat %>% 
    left_join(., shape_gaul_tbl, by = c("ADM0_CODE")) %>% 
    mutate_at(c("ADM0_NAME"), 
              funs(recode(.,'U.K. of Great Britain and Northern Ireland'  = 'United Kingdom of Great Britain and Northern Ireland',
                          "Czech Republic" = "Czechia"))) %>% 
    mutate_at(c("gridcode"), 
              funs(recode(.,'2' = 'peat',
                          "1" = "nopeat"))) %>% 
    mutate(frac_nopeat = non_peat_area_1_perc/100) %>% 
    mutate(frac_peat = peat_area_1_perc/100) %>% 
    rename(peat = gridcode)
}


# Creates a vector with repeating the above values where NAs 
repeat_last = function(x, forward = TRUE, maxgap = Inf, na.rm = FALSE) {
  if (!forward) x = rev(x)           # reverse x twice if carrying backward
  ind = which(!is.na(x))             # get positions of nonmissing values
  if (is.na(x[1]) && !na.rm)         # if it begins with NA
    ind = c(1,ind)                 # add first pos
  rep_times = diff(                  # diffing the indices + length yields how often
    c(ind, length(x) + 1) )          # they need to be repeated
  if (maxgap < Inf) {
    exceed = rep_times - 1 > maxgap  # exceeding maxgap
    if (any(exceed)) {               # any exceed?
      ind = sort(c(ind[exceed] + 1, ind))      # add NA in gaps
      rep_times = diff(c(ind, length(x) + 1) ) # diff again
    }
  }
  x = rep(x[ind], times = rep_times) # repeat the values at these indices
  if (!forward) x = rev(x)           # second reversion
  x
}  


# Loading vector data 
dat_spam=read_csv(here("Input_data", "spam2010V2r0_global_Y_TA.csv"))
dat_spam=dplyr::select(dat_spam, x,y, alloc_key, name_adm1, iso3)

# Make SPAM spatial 
# projcrs <- "+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0"
# proj_mercator = "+proj=merc +lon_0=0 +k=1 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs"
proj = "+proj=longlat +datum=WGS84 +no_defs +units=m" # taken from raster file below 
# proj_meter = "+datum=WGS84 +units=m +no_defs"
dat_cent <- st_as_sf(x = dat_spam,                         
                     coords = c("x", "y"),
                     crs = proj)

# Shapefile gaul 
shape_gaul=read_sf(here("Input_data", "g2015_2014_1.shp")) #actual GAUL map 
shape_gaul=dplyr::select(shape_gaul, ADM0_CODE, ADM0_NAME, geometry)
shape_gaul_tbl = shape_gaul %>%  as_tibble() %>% dplyr::select(-geometry) %>% 
  distinct_at("ADM0_CODE", .keep_all = T)


# country mapping
dat_map_SPAM_GAUL_CIFOS_FAO = read.csv(here("Input_data", "Mappings", "dat_map_SPAM_GAUL_CIFOS_FAO.csv")) %>%  as_tibble()
dat_map_SPAM_GAUL_CIFOS_FAO_full = dat_map_SPAM_GAUL_CIFOS_FAO %>% 
  dplyr::select(-M49_Code, -iso2_code_FAO, -iso3_code_FAO) %>% left_join(., FAOSTAT_cntr, by = c("name_cntr_FAO" = "Country")) #needs some more checking > NAs in last col
# dat_map_SPAM_GAUL_CIFOS_FAO = dat_map_SPAM_GAUL_CIFOS %>%  full_join(., FAOSTAT_cntr, c("name_cntr_GAUL2015" ="Country")) 
# write_csv(dat_map_SPAM_GAUL_CIFOS_FAO, here("Input_data", "Mappings", "dat_map_SPAM_GAUL_CIFOS_FAO.csv"))

# Distinct at SPAM 2010 
dat_map_SPAM_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(iso3_SPAM), .keep_all = T)
# Distinct at CIFOS 
dat_map_CIFOS_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(me_cntr_CIFOS2021), .keep_all = T) #correct
# Distinct at GAUL2015 
dat_map_GAUL2015_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(me_cntr_GAUL2015), .keep_all = T) #correct

# EU-28 susbett 
dat_map_GAUL2015_dist = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% distinct_at(vars(me_cntr_GAUL2015), .keep_all = T) #correct

# SUbsetting crop variables for EU28
crops_FAO_EU28 = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% filter(., iso3_SPAM  %in% EU_iso3) 



# Load Validation SPAM files and grassland files from CIFOS  model data - National level   --------------------------------------------------
validation_crop = read.csv(here("Input_data", "Core_data", "SPAM_Crops_EU28_alltecRec_nuts_veg.csv")) %>%  dplyr::select(-X1) %>% as_tibble()
validation_grass_area = read_csv(here("Input_data","Validation_data_CIFOS", "Grassland_area_CIFOS_EU.csv")) %>% as_tibble()
validation_grass_yield = read_csv(here("Input_data","Validation_data_CIFOS", "Grassland_yield_tidy.csv")) %>% as_tibble()

# Loading peat/nonpeat for cropland and pasture globally ------------------
peat_past_global = read.dbf(here("Input_data", "g2015_pasture_Peat_Hyde.dbf")) %>%  as_tibble()
peat_crop_global = read.dbf(here("Input_data", "g2015_Crop_Peat_Hyde.dbf")) %>%  as_tibble()

# country_mapping
cntr_map_global = read_sf(here("Input_data", "GAUL2008_SPAM_LINK", "GAUL2008_SPAM_LINK.shp")) #checked the map. IS te right GAUL map
Country_mapEU27 = validation_crop %>%  dplyr::select(iso3, Country) %>%  distinct_at("iso3", .keep_all = T) %>%
  rename("country" = "Country")
EU_iso3 = c("AUT","BEL", "BGR", "HRV", "CZE", "DNK", "EST","FIN", "FRA", "DEU", "GRC", "HUN", "IRL", "ITA","LVA",
            "LTU", "LUX", "MLT", "NLD", "POL", "PRT","ROU", "SVK","SVN", "ESP", "SWE", "GBR", "CYP")

# Running function on pasture and cropland datasets
crop_peat = Fun_percentage_peat(peat_crop_global)
past_peat = Fun_percentage_peat(peat_past_global)

# add a adm0 identifier over all three datasets
# Determining the allocation fraction between peat/non-peat production  
#creating alloaction factors for production 
SPAM_valid_aloc_crop = validation_crop %>% 
  dplyr::select(-Yield_kgha) %>%
  mutate(aloc_harv_prod = Production_mt/HarvestedArea_ha,
         aloc_phys_prod = Production_mt/PhysicalArea_ha) %>% 
  mutate_at(vars(aloc_harv_prod, aloc_phys_prod),
            ~replace(., is.nan(.), 0)) 


# Add to SPAM validation data
Join_SPAM_past_EU28 = validation_grass_area %>%  
  # mutate_at(c("country"), 
            # funs(recode(.,'United Kingdom'  = 'United Kingdom of Great Britain and Northern Ireland'))) %>%
  left_join(., past_peat, by=c("me_cntr_CIFOS2021 " = "ADM0_NAME")) %>% 
  left_join(., dat_map_CIFOS_dist, by = c("ADM0_CODE"="ADM0_CODE_GAUL")) %>% drop_na() %>% 
  mutate_at(c("peat"), 
            funs(recode(.,'frac_nopeat' = 'nopeat',
                        "frac_peat" = "peat")))%>% #distinct_at("iso3")
  mutate(area = case_when(land_type == "marginal" ~ area/100,
                               land_type == "arable" ~ area))

Join_SPAM_past_yield_EU27 = validation_grass_yield %>%  
  # mutate_at(c("country"), 
            # funs(recode(.,'United Kingdom'  = 'United Kingdom of Great Britain and Northern Ireland'))) %>%
  left_join(., past_peat, by=c("country" = "ADM0_NAME")) %>% 
  left_join(., dat_map_CIFOS_dist, by = "country") %>% drop_na() %>% 
  mutate_at(c("peat"), 
            funs(recode(.,'frac_nopeat' = 'nopeat',
                        "frac_peat" = "peat")))%>%  # %>% distinct_at("iso3")
  mutate_at(c("land_type"), funs(recode(.,'Arable' = 'arable')))# %>% 
write_csv(Join_SPAM_past_yield_EU27, here("Input_data","Validation_data_CIFOS", "Join_SPAM_past_yield_EU27.csv"))


Join_SPAM_crop_EU28 = SPAM_valid_aloc_crop %>%  left_join(., crop_peat, by=c("country_cifos" = "me_cntr_CIFOS2021")) %>% 
  mutate_at(c("peat"), 
            funs(recode(.,'frac_peat' = 'peat',
                        "frac_nopeat" = "nopeat")))

# 3. do the multiplication 
# Crops
EU_peat_crop_area_EU27 = Join_SPAM_crop_EU28 %>% 
  mutate(HarvestedArea_ha = HarvestedArea_ha*peat_frac) %>% 
  mutate(PhysicalArea_ha = PhysicalArea_ha*peat_frac) %>% 
  mutate(Production_mt  = HarvestedArea_ha*aloc_harv_prod) %>% 
  mutate(Yield_kgha  = Production_mt*1000/HarvestedArea_ha) %>%
  dplyr::select(iso3,country_cifos,crops_cifos,crops_spam,peat,HarvestedArea_ha,PhysicalArea_ha,Production_mt, Yield_kgha) %>% 
  mutate_at(vars(Yield_kgha), ~replace(., is.nan(.), 0))
write_csv(EU_peat_crop_area_EU27, here("Input_data","Validation_data_CIFOS", "EU_peat_crop_area_EU28_debug.csv"))

# Grass
EU_peat_past_area_EU27 = Join_SPAM_past_EU27 %>% 
  mutate(area = area*peat_frac) %>% 
  dplyr::select(iso3, country, land_type, peat, area)
write_csv(EU_peat_past_area_EU27, here("Input_data","Validation_data_CIFOS", "EU_peat_past_area_EU27.csv"))


# link grass area with yield
# Assumption: yields the same on peat/non-peat
area_yield_past = EU_peat_past_area_EU27 %>%  
  dplyr::select(iso3, country, land_type, peat, area) %>% 
  mutate_if(sapply(., is.character), as.factor) %>%
  right_join(., Join_SPAM_past_yield_EU27, by = c("iso3", "peat", "land_type")) %>% 
  # complete(nesting(intensity_level), rep)#%>%
    rename(country = country.x,) %>%
  dplyr::select(iso3, ADM0_CODE, country, land_type, intensity_level, grass_type,  peat, area, yield)%>% 
  expand(nesting(iso3, country, land_type,intensity_level, grass_type,  peat, yield, area)) %>%
  group_by(peat, iso3)%>% arrange(desc(peat))
  
area_yield_past$area <- repeat_last(area_yield_past$area)
area_yield_past$country <- repeat_last(area_yield_past$country)

area_yield_past_prod = area_yield_past %>% 
  mutate(Production_kg  = yield*area) 
write_csv(area_yield_past_prod, here("Input_data","Validation_data_CIFOS", "Grassland_allVar.csv"))


















# Joining with GAUl -------------------------------------------------------

# Multiplying with the area of the grassland and crop SPAM dataset --------



  
  mutate_at(c("name_adm1"), funs(recode(.,'North East (UK)'  = 'East Midlands (UK)',
                                        'North West (UK)'  = 'East Midlands (UK)',
                                        'Yorkshire and The Humber'  = 'East Midlands (UK)',
                                        'West Midlands (UK)'  = 'East Midlands (UK)',
                                        'East of England'  = 'East Midlands (UK)',
                                        'South East (UK)'  = 'East Midlands (UK)',
                                        'South West (UK)'  = 'East Midlands (UK)',
                                        'London'  = 'East Midlands (UK)',
                                        'Strední Morava' = 'Strední Cechy',
                                        'Kriva Palanka'  = 'Kumanova',
                                        'Nor Oriental'  = 'Gracias A Dios',
                                        'Nororiente'  = 'Sucumbios',
                                        'Mzuzu'  = 'Karonga',
                                        'Salima'  = 'Kasungu',
                                        'Lilongwe'  = 'Kasungu',
                                        'Blantyre'  = 'Machinga',
                                        'Shire valley'  = 'Machinga')))


# SUbsetting EU-27
EU_iso3 = c("AUT","BEL", "BGR", "HRV", "CZE", "DNK", "EST","FIN", "FRA", "DEU", "GRC", "HUN", "IRL", "ITA","LVA", 
            "LTU", "LUX", "MLT", "NLD", "POL", "PRT","ROU", "SVK","SVN", "ESP", "SWE", "GBR")

cntr_EU2_gaul_shape = cntr_map_global %>% #Pixel level data
  filter(iso3 %in% EU_iso3) %>% 
  dplyr::select(alloc_key,G2008_1_ID,iso3,name_cntr,name_adm1,ADM1_CODE, ADM0_CODE)  
# distinct_at(vars(G2008_1_ID, iso3)) %>% 
# st_join(., shape_gaul, join = st_intersects, right = T)

# With this shape file we can clip the extent of EU27 area
gaul_EU27 = st_join(shape_gaul, cntr_EU2_gaul_shape, join = st_intersects, left = T) %>% 
  drop_na() %>% 
  distinct_at(vars(G2008_1_ID.x, alloc_key, ADM1_NAME, ADM0_NAME, geometry)) %>% 
  rename(
    # ADM1_NAME =ADM1_NAME.x,
    # ADM0_NAME =ADM0_NAME.x,
    G2008_1_ID =G2008_1_ID.x) %>% 
  st_as_sf()

# write_sf(gaul_EU27, here("Input_data", "gaul_EU27.shp"))
read_sf(here("Input_data", "gaul_EU27.shp"))

# tHIS IS FOR Futther clipping
gaul_uniq_EU27 = gaul_EU27 %>% 
  as_tibble() %>% 
  dplyr::select(-alloc_key) %>% 
  distinct_all() %>% 
  st_as_sf #%>% 
  # write_sf(here("Input_data", "gaul_uniq_EU27.shp"))

gaul_unique_EU27 = read_sf((here("Input_data", "gaul_uniq_EU27.shp")))

# verifying the clipping. Issue: looks skewed in the norther countries.. 
plot(gaul_uniq_EU27 %>% dplyr::select(ADM1_NAME))

# # Check if 27 EU memeberstates > CORRECT!
# lengthEU27 = gaul_EU27 %>% 
#   as_tibble() %>% 
#   distinct_at(vars(ADM0_NAME)) 

# Loading raster data 
dat_rast_SOC = raster(here("Input_data", "sol_organic.carbon_usda.tif"))


# dat_rast_SOC_perc <- dat_rast_SOC/2 #conversion to percentage according to openlandmap website
# writeRaster(dat_rast_SOC_perc, here("Input_data", "dat_SOC_USDA_percent.tiff")) #validated 
dat_rast_SOC_perc=raster(here("Input_data", "dat_SOC_USDA_percent.tif"))
# crs(dat_rast_SOC_perc)

# Reclassify raster  ------------------------------------------------------
# https://www.earthdatascience.org/courses/earth-analytics/lidar-raster-data-r/classify-raster/

# # Creating threshold for reclassification 
# reclass_df <- c(0, 30, 0,
#                 30, Inf, 1)
# 
# # reshape the object into a matrix with columns and rows
# reclass_m <- matrix(reclass_df,
#                     ncol = 3,
#                     byrow = TRUE)
# # reclassify the raster using the reclass object - reclass_md
# SOC_reclas <- reclassify(dat_rst_SOC_perc,
#                          reclass_m)
# 
# writeRaster(SOC_reclas, here("Input_data", "SOC_reclass_perc.tif"))
# SOC_reclass = raster(here("Input_data", "SOC_reclass_perc.tif"))
# 

# Clip raster  ------------------------------------------------------------
# https://www.earthdatascience.org/courses/earth-analytics/lidar-raster-data-r/crop-raster-data-in-r/
crop_extent <- read_sf(here("Input_data", "gaul_uniq_EU27.shp"))

# Plot raster 
# plot(dat_rast_SOC_perc) #validated as hald of dat_rast_SOC below
# # plot(dat_rast_SOC)
# 
# # Plot shapefile
# plot(crop_extent %>%dplyr::select(ADM1_CODE),
#      main = "Shapefile imported into R - crop extent",
#      axes = T,
#      border = "blue")
# 
# # crop the lidar raster using the vector extent
# SOC_test_perc <- crop(dat_rast_SOC_perc, crop_extent)
# plot(crop, main = "Cropped soc perc")
# 
# # add shapefile on top of the existing raster
# plot(crop_extent, add = TRUE)
# 
# plot(gaul_uniq_EU27)
# # EU raster CLIP
EU27_area_clip <- crop(dat_rast_SOC_perc, gaul_uniq_EU27)
# plot(EU27_area_clip)
# plot(dat_rast_SOC_perc)
writeRaster(EU27_area_clip, here("Input_data", "EU27Areaclip.tif"))
EU27_area_clip = raster(here("Input_data", "EU27Areaclip.tif"))
# Note: takes only a few seconds for EU

## Raster to point polygon (https://geocompr.robinlovelace.net/geometric-operations.html#spatial-vectorization)
Sys.time()
SOC_perc_EU27_points = rasterToPoints(EU27_area_clip, spatial = TRUE)
Sys.time()

save(SOC_perc_EU27_points,file=here("Input_data", "SOC_points_perc_EU.RData")) 

gc(reset=T)

Sys.time()
st_as_sf(SOC_perc_EU27_points)
Sys.time()



# # Alternatively to convert raster to points
# SOC_perc_EU27_points_sf = st_as_sf(EU27_area_clip, as_points = TRUE, merge = FALSE)
# ?st_as_sf
# 
# 
# write_sf(SOC_perc_EU27_points, here("Input_data", "SOC_perc_EU27_points.shp")) # memory exhaust
# Sys.time()
# # max(SOC_points)
# > summary(SOC_points$sol_organic.carbon_usda)
# Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 0.000   4.000   5.000   5.877   7.000  60.000 


# HWSD map ----------------------------------------------------------------
# Here the  polygon is imported - this shape file was created in Qgis 
SOC_perc_EU27Q = st_read(here("Input_data","point_soc_perc_EU.shp"))

gaul_unique_EU27 = read_sf((here("Input_data", "gaul_uniq_EU27.shp")))
SOC_topsoil_SOCperc_HWSD_Q= st_read(here("Input_data","SOC_topsoil_SOCperc_HWSD_Q.shp"), 
                                    agr = c(SOC = "constant"))
SOC_topsoil_SOCperc_HWSD_Q 
## Spatial Join with SPAM pixels 
# All SOC points are remained and only in next step summarized
Sys.time()
Join_SOC_gaul_EU27_HWSD = st_join(SOC_topsoil_SOCperc_HWSD_Q, gaul_unique_EU27, join = st_intersects, left = T)
Sys.time()
# 
# intersection = st_intersection(SOC_topsoil_SOCperc_HWSD_Q,gaul_unique_EU27)# 
# Join_SOC_gaulLeft_EU27_HWSD = st_join(gaul_unique_EU27, SOC_topsoil_SOCperc_HWSD_Q)
# plot(Join_pointSOC_gaul_EU27_HWSD)
# plot(gaul_uniq_EU27)

# Recalulating area - since we do not have point polygons 
SOC_HWSD = Join_SOC_gaul_EU27_HWSD %>% 
  # rowwise() %>% 
  mutate(area = geometry %>%
           st_zm() %>%
           st_area())
# test area
lapland = SOC_HWSD %>% filter(ADM1_NAME == "Lapland") %>% 
  as_tibble() %>% 
    summarise(sum(area))
#Finland Lappland = 403498.752337km2 - h

# Define new factors peat nonpeat based on SOC condition 
SOC_prop_HWSD = SOC_HWSD %>% 
  rowwise() %>% 
  mutate(peat = ifelse(SOC >= 30, "peat", "non_peat")) %>% #rowwise assigning peat non_peat as grouping variabkle
  group_by(ADM1_NAME, peat) %>% 
  mutate(area_adm1 = sum(area)) %>% 
  ungroup() %>% 
  distinct_at(.vars = 4)

# Here we calulate the share of peat and non peat per adm1 units 
# computationally intense > takes a few minutes only for EU
SOC_prop_HWSD1 = SOC_prop_HWSD %>% 
  group_by(ADM1_NAME, ADM0_NAME, peat) %>% 
  summarise(area_n_peat = mean(area_adm1))

SOC_prop_HWSD2= SOC_prop_HWSD1 %>%
  as_tibble() %>%
  group_by(ADM1_NAME) %>% 
  mutate(area_peat_prop = (area_n_peat)/sum(area_n_peat)*100) #%>% 
  # write_sf(here("Input_data", "SOC_perc_adm1_EU27_HWSD.shp"))

gaul_tbl = gaul_unique_EU27 %>% 
  as_tibble() %>% 
  dplyr::select(G2008_1_ID, ADM0_NAME, ADM1_NAME)

# Creating a csv file without eometries
SOC_gaul_HWSD_EU27_PEAT=SOC_prop_HWSD2  %>% 
  dplyr::select(ADM0_NAME, ADM1_NAME, peat, area_peat_prop) %>% 
  right_join(.,gaul_tbl, by="ADM1_NAME") %>% 
  dplyr::select(-G2008_1_ID) %>% 
  group_by(ADM1_NAME, peat) %>% 
  distinct() %>% 
  write_csv(here("Input_data", "SOC_gaul_HWSD_EU27_PEAT.csv")) 




# Join back the ADM0 
PEAT_gaul_EU27_HWSD = st_join(SOC_prop_HWSD2, gaul_unique_EU27, join = st_intersects, left = T)


# write_csv(SOC_prop_HWSD2, here( "Input_data", "SOC_perc_adm1_EU27_HWSD.csv" ))
peat = read_csv(here("Input_data", "SOC_perc_adm1_EU27_HWSD.csv"))

# Checking the peat data 
# Checking peat tibble data = area per peat and country
SOC_gaul_HWSD_EU27_PEAT_check = SOC_gaul_HWSD_EU27_PEAT%>%                              # Applying group_by & summarise
  group_by(ADM0_NAME.x, peat) %>%
  summarize(mean(area_peat_prop)) %>% 
  write_csv(here("Input_data", "SOC_perc_adm0ag_EU27_HWSD.csv"))



peat2 = peat %>%  
  group_by(ADM1_NAME, peat) %>% 
  summarise(area_peat_prop) %>% 
  st_as_sf() 
  st_join()

# max peat values. 
peatmax = peat %>%  
  filter(peat == "peat") %>% 
  arrange()

Gaul_area = gaul_unique_EU27 %>%  
  rowwise() %>% 
  mutate(area = geometry %>%
           st_zm() %>%
           st_area())
#area finland
HWSDSOC_area =SOC_topsoil_SOCperc_HWSD_Q%>%  
  rowwise() %>% 
  mutate(area = geometry %>%
           st_zm() %>%
           st_area())
#area finland

# Area checked for Lapland finland > real=10000km2. here=98859km2.

# Join data back to 



# Removing NAs - areas which are not in the area of EU27 show NA
SOC_GAUL = Join_pointSOC_gaul_EU27 %>% 
  drop_na() %>% 
  
         




write_sf(Join_pointSOC_gaul_EU27, here("Input_data", "Join_pointSOC_gaul_EU27.shp"))
# Test time: for ~9mio points we need ~3 min
# start: "2021-01-25 21:58:05 CET"
# end: "2021-01-25 22:00:53 CET"

## Calculate the summary statistic


# HWSD Intersection  ------------------------------------------------------
gaul_unique_EU27 = read_sf((here("Input_data", "gaul_uniq_EU27.shp")))
SOC_topsoil_SOCperc_HWSD_Q= st_read(here("Input_data","SOC_topsoil_SOCperc_HWSD_Q.shp"), 
                                    agr = c(SOC = "constant"))
intersection_SOC_gaulLeft_EU27_HWSD = st_intersection(st_make_valid(gaul_unique_EU27), st_make_valid(SOC_topsoil_SOCperc_HWSD_Q))
# area
SOC_HWSD_intersection = intersection_SOC_gaulLeft_EU27_HWSD %>% 
  rowwise() %>% 
  mutate(area = geometry %>%
           st_zm() %>%
           st_area())

# 1- Define new factors peat nonpeat based on SOC condition 
SOC_prop_HWSD_insectn = intersection_SOC_gaulLeft_EU27_HWSD %>% 
  rowwise() %>% 
  mutate(peat = ifelse(SOC >= 30, "peat", "non_peat")) #rowwise assigning peat non_peat as grouping variabkle
  
# aggregate to adm1 level https://r-spatial.github.io/sf/reference/aggregate.sf.html
SOC_prop_HWSD_insectn_adm1 = SOC_prop_HWSD_insectn %>% 
  aggregate(x= .$SOC, by = list(ADM0_NAME, ADM1_NAME, peat), FUN = "mean")
  
  group_by(ADM1_NAME, peat) 


#%>% 
  mutate(area_adm1 = sum(area)) %>% 
  ungroup() %>% 
  distinct_at(.vars = 4)




# PEAT with zonal statistics  ---------------------------------------------
# https://stackoverflow.com/questions/47691200/raster-in-r-create-zonal-count-of-specific-cell-values-without-reclassification

# 
# I would like to know if there is way to create zonal statistics for RasterLayerObjects, specifically the count of a given cell value (e.g. a land-use class) in R without having to reclassify the whole raster. The solution should be memory efficient in order to work on large raster files i.e. no extraction of the values into a matrix in R is desired.
# 
# Below an example of how I handle it until now. In this case I reclassify the original raster to hold only 1 for the value of interest and missings for all other values.
# 
# My proposed solution creates both, redundant data and additional processing steps to get me to my initial goal. I thought something like zonal(r1[r1==6],r2,"count") would work but obviously it does not (see below).

# generate reproducible Raster 
library("raster")

## RASTER 1 (e.g. land-use classes)
r1 <- raster( crs="+proj=utm +zone=31")
extent(r1) <- extent(0, 100, 0, 100)
res(r1) <- c(5, 5)
values(r1) <- sample(10, ncell(r1), replace=TRUE)
plot(r1)

## RASTER 2 (containing zones of interest)
r2 <- raster( crs="+proj=utm +zone=31")
extent(r2) <- extent(0, 100, 0, 100)
res(r2) <- c(5, 5)
values(r2) <- c(rep(1,100),rep(2,100),rep(3,100),rep(4,100))
plot(r2)

# (1) ZONAL STATISTICS
# a. how many cells per zone (independent of specific cell value)
zonal(r1,r2,"count")

# b. how many cells per zone of specific value 6
zonal(r1[r1==6],r2,"count")
# -> fails

# with reclassification
r1.reclass<-
  reclassify(r1,
             matrix(c(1,5,NA,
                      5.5,6.5,1, #class of interest 
                      6.5,10,NA),
                    ncol=3,
                    byrow = T),
             include.lowest=T # include the lowest value from the table.
  )
zonal(r1.reclass,r2,"count")


