easypackages::packages(c("tidyverse", 'sf', 'raster','sp', 'spatialEco',
                         'exactextractr', 'here', "readxl", "foreign", "data.table", "rbenchmark", "benchmarkme",
                         "validate", "forcats"))

# Set working directory
setwd(here::here("Input_data"))


# Functions ---------------------------------------------------------------

# This function lists all the SPAM files for the three rec_types and then reads 
# them in with a certain encoding that keeps all the names as they should be 
load_list_SPAM <- function(path, type) {
  pattern <- switch (type,
                     "harv" = c("_H_", "*.csv$"),
                     "phys" = c("_A_", "*.csv$"),
                     "prod" = c("_P_", "*.csv$"))
  path <- list.files(path = path,
                     full.names = TRUE,
                     pattern = pattern)
  l_read_csv <- lapply(path, readr::read_csv, locale = locale(encoding = "WINDOWS-1252"),#local(encoding = "WINDOWS-1252"))
                       col_types = cols(alloc_key = col_double())) #the alloc_key is set numeric 
  crop_names <- stringr::str_extract(basename(path), "^.+(?=_)")
  names(l_read_csv) <- crop_names
  return(l_read_csv)
}

# Load data  --------------------------------------------------------------

# Tabular SPAM ------------------------------------------------------------
# Production 
SPAM_prod = load_list_SPAM(path=here::here("Input_data"), type = "prod") #list of all production spam files
SPAM_prod = bind_rows(SPAM_prod)

# Harvested area
SPAM_harv = load_list_SPAM(path=here::here("Input_data"), type = "harv") #list of all harvested area spam files
SPAM_harv = bind_rows(SPAM_harv)

# Physical area
SPAM_phys = load_list_SPAM(path=here::here("Input_data"), type = "phys") #list of all physical area spam files
SPAM_phys = bind_rows(SPAM_phys)

# Spatial SPAM ------------------------------------------------------------
# Single SPAM file for spatial file creation
dat_TA_pr <- read_csv(here::here("Input_data", "spam2010V2r0_global_P_TA.csv"),locale = locale(encoding = "WINDOWS-1252"))

# Create a spatial SPAM file 
geo_spam=dplyr::select(dat_TA_pr, x,y, cell5m, name_adm1, iso3) 
# %>% 
  # distinct_at(vars(name_adm1))

# Make SPAM spatial 
# projcrs <- "+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0"
# proj_mercator = "+proj=merc +lon_0=0 +k=1 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs"
proj = "+proj=longlat +datum=WGS84 +no_defs +units=m" # taken from raster file below 
proj_meter = "+datum=WGS84 +units=m +no_defs"
geo_spam1 <- st_as_sf(x = geo_spam,                         
                     coords = c("x", "y"),
                     crs = proj)

# Load administrative unit shapefile which matches the SPAM adm1 zones
# Admin0 = st_read(here::here("Input_data","GAUL_GADM_SPAM_ULRIKE", "g2008_0_now","g2008_0.shp"))
Admin1 = st_read(here::here("Input_data","GAUL_GADM_SPAM_ULRIKE", "g2008_1_now","g2008_1.shp")) #this is what we need
# Admin2 = st_read(here::here("Input_data","GAUL_GADM_SPAM_ULRIKE", "g2008_2_2020_11_02","g2008_2.shp")) #this is what we need

# Here I manually adjusted the NAME1 values to the once used in SPAM2010. see Documentation for more. 
Admin1Adj = st_read(here::here("Input_data","g2008_1_now", "g2008_1.shp"), options = "ENCODING=WINDOWS-1252")#WINDOWS-1252

# Now the values from GGS that are still not matching the SPAM2010 adm1 values are recoded
Admin1Adj2 = Admin1Adj %>% as_tibble() %>% 
  mutate(NAME1 = case_when(ADM0_CODE == 196 & #Philipines
                            NAME1 =="Autonomous region in Muslim Mindanao (ARMM)"~ "Autonomous region in Muslim Mi",
                         TRUE ~ NAME1)) %>%
  mutate(NAME1 = case_when(ADM0_CODE == 196 & #Philipines
                           NAME1 =="Region IX (Zamboanga Peninsula)" ~ "Region IX (Zamboanga Peninsula",
                         TRUE ~ NAME1)) %>% 
  mutate(NAME1 = case_when(#ADM0_CODE == 19 & #Azerbaijan
                             NAME1 =="Administrative unit not available" ~ "Administrative unit not availa",
                           TRUE ~ NAME1)) %>% 
  mutate(NAME1 = case_when(#ADM0_CODE == 152 & #Malawi
                             NAME1 =="Area under National Administration" ~ "Area under National Administra",
                           TRUE ~ NAME1)) %>% 
  mutate(NAME1 = case_when(ADM0_CODE == 196 & #Philipines
                             NAME1 =="Cordillera Administrative region (CAR)" ~ "Cordillera Administrative regi",
                           TRUE ~ NAME1)) %>% 
  mutate(NAME1 = case_when(#ADM0_CODE == 196 & #Philipines
                             NAME1 =="Autonomous region in Muslim Mindanao (ARMM)"~ "Autonomous region in Muslim Mi",
                           TRUE ~ NAME1)) %>%
  mutate(NAME1 = case_when(ADM0_CODE == 108 & #Haiti
                             NAME1 =="NOROESTE" ~ "Nord-Est",
                           TRUE ~ NAME1)) %>% 
  mutate(NAME1 = case_when(ADM0_CODE == 111 & # Honduras
                             NAME1 =="Nor Oriental" ~ "Gracias A Dios", 
                           TRUE ~ NAME1))

# Define projection for GAULGADMSPAM
proj = "+proj=longlat +datum=WGS84 +no_defs +units=m" # taken from raster file below 
proj_meter = "+datum=WGS84 +units=m +no_defs"
AdminAdj2.2 <- st_as_sf(x = Admin1Adj2,                         
                      # coords = c("x", "y"),
                      crs = proj)

# Joining SPAM df and GAUL-GADM-SPAM --------------------------------------

# Ulrike's comment: Shape files for GAUL-GADM-SPAM
# Please note that the columns fips0, fips1 and fips2 are the ones which have the codes for admin level 0 (country), level 1 and level 2 which can be linked to SPAM results.
# The matching names are in columns Adm0_name, name1 and name2.# 
# Columns which have names O_fips1, O_fips2, O_name1 and O_name2 refer to an “old” classification system at level 1 and level 2. Its entries differ from the columns without “O_” in some EU countries and a few others where the statistic units did not match the admin units. Please note that the shape files themselves were not modified, only the entries in the dbf tables. 

# # adm1 unit match check
# spam_admin_link = dat_TA_pr%>% dplyr::select(iso3, cell5m, name_cntr, name_adm1) %>% 
#   group_by(name_adm1, iso3) %>% 
#   distinct_at(vars(name_adm1), .keep_all = T) %>% 
#   full_join(., AdminAdj2.2, by=c("name_adm1"="NAME1"))
# 
# # I need to get the adm1 units unique per country otherwise generic terms will be merged (like no "administrative units") 
# adm1_distinctAdj=AdminAdj2.2 %>% as_tibble() %>% 
#   group_by(NAME1, ADM0_NAME) %>% 
#   distinct_at(vars(NAME1), .keep_all = T)
# # str(Admin1)
# 
# # test
# test1=test %>% as_tibble() %>%
#   group_by(alpha, beta) %>% 
#   distinct_at(vars(beta), .keep_all = T)
# str(Admin1)
# 
# adm1_distinct=as_tibble(Admin1) %>% 
#   distinct_at(vars(FIPS1))#, .keep_all = T)
# 
# # adm2 units 
# adm2o_distinct=as_tibble(Admin1) %>% 
#   distinct_at(vars(O_NAME))#, .keep_all = T)
# 
# adm2_distinct=as_tibble(Admin1) %>% 
#   distinct_at(vars(FIPS1))#, .keep_all = T)
# 
# # Validation - Making sure SPAM2010 matches with admin Shapefiles 

# Adm0 - unique countries 
# SPAM2010
# 201 (name_cntr)
# 201 (iso3)

# ADM1 GAUL_SPAM_GADM
# > 275 (ADM0_NAME)
# > 250 (FIPS0)
# 

# ADM1
# 1. Same amount of rows when distinct adm1 names? 

# SPAM2010 Admin1 units
# 2493 (name_adm1)

# ADM1 GAUL_SPAM_GADM
# 3230 (NAME1)
# 3079 (O_NAME1
# 2898 (FIPS1)

# ADM2 GAUL_SPAM_GADM
#  3080 (O_NAME1)
#  2758 (NAME1)
#  3222 (O_FIPS1)
#  2898 (FIPS1)

# How to deal with inconsistency? 
# 1. Spatial join 
# 2. Fulljoin > detect NA's then check what is different

# Spatial join 
# join_SPAM_adm1 = st_join(Admin1, geo_spam1, join = st_intersects, largest = T)

# the final adm1 units are calculated by first full join and then by removing the NAs (=all variables that are not
# in the SPAM2010 and some that are not represented in the GGS (no shapes available for England subunits for example)).
# Finally, we have now 2468 adm1 units globally (of initially  2493 adm1 units; Diff: 25 adm1 units). The area of these
# 25 adm1 units needs to be added to the representative units. Otherwise, the total arable land will be off. TODO! 

# # Disinct GGS adjusted
# adm1_distinctAdj=AdminAdj2.2 %>% as_tibble() %>% 
#   group_by(NAME1, ADM0_NAME) %>% 
#   distinct_at(vars(NAME1), .keep_all = T)
# #2,741 rows
# 
# # Distinct SPAM2010
# spam_admin_link = dat_TA_pr %>% dplyr::select(iso3, cell5m, name_cntr, name_adm1) %>% 
#   group_by(name_adm1, iso3) %>%
#   distinct_at(vars(name_adm1), .keep_all = T)  
# #2,493 (diff=248)

# Left joining the SPAM2010 and GGS adjusted.
# This function's result is the final Shapefile that matches SPAM2010 adm1 
# (-17 that are not in the GGS but will be merged into other adm1 units)
FINAL_adm1_spam2010_GGS_distinct = dat_TA_pr %>% dplyr::select(iso3, cell5m, name_cntr, name_adm1) %>% 
  group_by(name_adm1, iso3) %>%
  distinct_at(vars(name_adm1), .keep_all = T) %>%
  left_join(., AdminAdj2.2, by=c("name_adm1" = "NAME1")) %>% 
  # dplyr::select(iso3, cell5m, name_adm1, ADM1_CODE, FIPS1, FIPS0) %>% 
  drop_na(ADM1_CODE) %>% 
  distinct_at(vars(name_adm1), .keep_all = T) 

# Converting to shapefile
ADM1_SPAM_GGS = st_as_sf(FINAL_adm1_spam2010_GGS_distinct)
proj = "+proj=longlat +datum=WGS84 +no_defs +units=m" # taken from raster file below 
proj_meter = "+datum=WGS84 +units=m +no_defs"
ADM1_SPAM_GGS <- st_as_sf(x = ADM1_SPAM_GGS,                         
                        # coords = c("x", "y"),
                        crs = proj)


# Writing Adm1 zone files tabular and spatial -----------------------------
write_csv(FINAL_adm1_spam2010_GGS_distinct, here::here("Input_data", "Core_data",  "ADM1_SPAM2010_GGS.csv"))
# st_write(ADM1_SPAM_GGS, here::here("Input_data", "Core_data",  "ADM1_SPAM2010_GGS_geo.shp"),
# driver = "ESRI Shapefile", options = "ENCODING=UTF-8")

# Mind the "WINDOWS-1252" encoding when reading in the ADM1_SPAM_GGS 
# ADM1_SPAM_GGS_loaded = st_read(here::here("Input_data", "Core_data",  "ADM1_SPAM2010_GGS_geo.shp"), options = "ENCODING=WINDOWS-1252") #encoding correct


# Validation questions:  --------------------------------------------------
# 1. What is the amount of adm1 units in the initial SPAM2010 data?
# SPAM2010/Adm1: Without grouping per country  = 2,493 
# SPAM2010/ADm1: With grouping per country     = 2,586  (-> Diff=93)

# 2. How many adm1 units are not represented in SPAm2010 but are in GGS? 
# with drop na: 2569 >> The amount of NAs in a left-join indicates which values in SPAM2010 are not available in GGS.
# without drop na: 5869 # Difference between so 2869-2569=300 units are not in SPAM that would actually be in GGS. 
# The number seems very high but I saw also that these reperesent many tiny islands around the world. So we just
# work with the assumption that SPAM2010 considered which adm1 units were important for crop growth and which not. 

# 3. How many units are there in the SPAM2010 but not in GGS? 
# 2586 (without drop_na) >> this indicates the df after left_join includin the na's indicating the adm1 units in SPAM but not in GGS
# 2569(with drop na) -> Difference between na and no-na is 17 -> These are the values that are in SPAM but 
# 17 adm1 units are that are in SPAM2010 are not in GGS! 

# 4. What are the adm1 units that need merging? 
# From the set of adm1 nits that are in SPAM but not in GGS we need to filter those who are combined together.
# Only then we can sum the correct area (both physical and harvested). 

# iso3	name_adm1	                  Merged with
# GBR	  North East (UK)	            East Midlands (UK)
# GBR	  North West (UK)	            East Midlands (UK)
# GBR	  Yorkshire and The Humber	  East Midlands (UK)
# GBR	  West Midlands (UK)	        East Midlands (UK)
# GBR	  East of England	            East Midlands (UK)
# GBR	  South East (UK)	            East Midlands (UK)
# GBR	  South West (UK)	            East Midlands (UK)
# GBR	  London	                    East Midlands (UK)
# CZE	  StrednÃ¬ Morava	            Strední Cechy
# MKD	  Kriva Palanka	              Kumanova
# HND	  Nor Oriental	              Gracias A Dios
# ECU	  Nororiente	                Sucumbios
# MWI	  Mzuzu	                      Karonga
# MWI	  Salima	                    Kasungu
# MWI	  Lilongwe	                  Kasungu
# MWI	  Blantyre	                  Machinga
# MWI	  Shire valley	              Machinga


# Loading treenut raster files  ------------------------------------------------
# Functions Treenuts
load_list_raster <- function(path, type) {
  pattern <- switch (type,
                     "yield" = "_YieldPerHectare\\.tif",
                     "area" = "_HarvestedAreaHectares\\.tif",
                     "prod" = "_Production\\.tif")
  path <- list.files(path = path, 
                     full.names = TRUE,
                     pattern = pattern)
  l_raster <- lapply(path, raster::raster)
  # crop_names <- stringr::str_extract(basename(path), "^.+(?=_)")
  # names(l_raster) <- crop_names
  return(l_raster)
}

# Exctracting treenuts and rest area and productio value per adm1 zones 
FunZone_sum=function(rast){ # raster and vector
  c=zonal.stats(ADM1_SPAM_GGS, rast, stats = c("sum")) 
  c$name_adm1 <- ADM1_SPAM_GGS$name_adm1  # assigning the identifier of the original df to the extracted df
  dat <- left_join(ADM1_SPAM_GGS, c, by = 'name_adm1') # merge the two files together
}

FUN_select_values = function(DF_list){
  dplyr::select(DF_list, starts_with("sum")) %>% as_tibble() %>% 
    dplyr::select(-geometry)
}

# Create factors based on other factors conditionally
FunFactCond = function(df, match_vec){
  df %>% mutate(first_tx = ifelse(name %in% match_vec, "tnuts", "rest"))
}

# Load treenut data -------------------------------------------------------
# Load harvested area and production raster data
rast_harv = load_list_raster(path=here::here("Input_data"), type = "area")
rast_prod = load_list_raster(path=here::here("Input_data"), type = "prod")

# Zonal statistics Treenuts -----------------------------------------------
lst_ex_pd = lapply(rast_prod, FunZone_sum)
lst_ex_ha = lapply(rast_harv, FunZone_sum)

# Select the extraction value columns
lst_values_pd = lapply(lst_ex_pd, FUN_select_values)
lst_values_ha = lapply(lst_ex_ha, FUN_select_values)

# Merging all lists together to a df
dat_ex_pd = do.call("cbind", lst_values_pd) # merging all tech types
dat_ex_ha = do.call("cbind", lst_values_ha)

# vector containing all tnuts names 
tnuts_vec = c("sum.walnut_Production", "sum.almond_Production","sum.chestnut_Production",
              "sum.cashew_Production","sum.pistachio_Production","sum.hazelnut_Production",
              "sum.brazil_Production","sum.nutnes_Production")


# production values tnuts adm1 --------------------------
treenut_pd = lst_ex_pd[[2]] %>% as_tibble() %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT, geometry) %>% 
  bind_cols(., dat_ex_pd) %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, 
                CONTINENT, matches("^sum\\..+_Production$"), geometry) %>%   
  group_by(iso3, name_adm1) %>% 
  mutate(treenut_pd = sum(sum.walnut_Production, 
                          sum.almond_Production,
                          sum.chestnut_Production,
                          sum.cashew_Production,
                          sum.pistachio_Production,
                          sum.hazelnut_Production,
                          sum.brazil_Production,
                          sum.nutnes_Production)) %>%
  mutate(rest_pd = sum(sum.aniseetc_Production,
                       sum.chilleetc_Production,
                       sum.kolanut_Production,
                       sum.areca_Production,
                       sum.cinnamon_Production,
                       sum.ginger_Production,
                       sum.hop_Production,
                       sum.mate_Production, 
                       sum.nutmeg_Production,
                       sum.pepper_Production,
                       sum.peppermint_Production,
                       sum.pyrethrum_Production,
                       sum.ramie_Production,
                       sum.rubber_Production,
                       sum.spicenes_Production,
                       sum.sugarnes_Production,
                       sum.vanilla_Production)) %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT,treenut_pd, rest_pd)
  
  
# validation of aggregation 
# Validate_agg = xcv %>%dplyr::select(tnuts_vec, iso3, name_adm1) %>% 
  # pivot_longer(cols = starts_with("sum."),
               # names_to = "Nuts", 
               # values_to = "value")

# calcluating the harvested area values for treenuts --------------------------
treenut_ha = lst_ex_ha[[2]] %>% as_tibble() %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT, geometry) %>% 
  bind_cols(., dat_ex_ha) %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, 
                CONTINENT, matches("^sum\\..+_HarvestedAreaHectares$"), geometry) %>%   
  group_by(iso3, name_adm1) %>% 
  mutate(treenut_ha = sum(sum.walnut_HarvestedAreaHectares, 
                          sum.almond_HarvestedAreaHectares,
                          sum.chestnut_HarvestedAreaHectares,
                          sum.cashew_HarvestedAreaHectares,
                          sum.pistachio_HarvestedAreaHectares,
                          sum.hazelnut_HarvestedAreaHectares,
                          sum.brazil_HarvestedAreaHectares,
                          sum.nutnes_HarvestedAreaHectares)) %>%
  mutate(rest_ha = sum(sum.aniseetc_HarvestedAreaHectares,
                       sum.chilleetc_HarvestedAreaHectares,
                       sum.kolanut_HarvestedAreaHectares,
                       sum.areca_HarvestedAreaHectares,
                       sum.cinnamon_HarvestedAreaHectares,
                       sum.ginger_HarvestedAreaHectares,
                       sum.hop_HarvestedAreaHectares,
                       sum.mate_HarvestedAreaHectares, 
                       sum.nutmeg_HarvestedAreaHectares,
                       sum.pepper_HarvestedAreaHectares,
                       sum.peppermint_HarvestedAreaHectares,
                       sum.pyrethrum_HarvestedAreaHectares,
                       sum.ramie_HarvestedAreaHectares,
                       sum.rubber_HarvestedAreaHectares,
                       sum.spicenes_HarvestedAreaHectares,
                       sum.sugarnes_HarvestedAreaHectares,
                       sum.vanilla_HarvestedAreaHectares)) %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT,treenut_ha, rest_ha)


# write and read tnuts geo data -------------------------------------------
# st_write(treenut_pd, here::here("Input_data", "Core_data",  "GSS_treenut_rest_pd.shp"),
#          driver = "ESRI Shapefile", options = "ENCODING=UTF-8")
# st_write(treenut_ha, here::here("Input_data", "Core_data",  "GSS_treenut_rest_ha.shp"),
#          driver = "ESRI Shapefile", options = "ENCODING=UTF-8")
# 
# treenut_ha = read_sf(here::here("Input_data", "GSS_treenut_rest_ha.shp"), options = "ENCODING=WINDOWS-1252")
# treenut_pd = read_sf(here::here("Input_data", "GSS_treenut_rest_pd.shp"), options = "ENCODING=WINDOWS-1252")

# # Converting to tibble
# sph.prod.tib = treenut_pd %>% as_tibble()
# sph.harv.tib = treenut_ha %>% as_tibble()

# Loading Shapefile GGS
ADM1_SPAM_GGS = st_read(here::here("Input_data", "Core_data",  "ADM1_SPAM2010_GGS_geo.shp"), options = "ENCODING=WINDOWS-1252")
ADM1_SPAM_GGS_tib = ADM1_SPAM_GGS %>% as_tibble()

# Aggregate tree nuts to to adm1 unit ---------------------------------------
# Production
prod.tib.adm1 = treenut_pd %>% as_tibble() %>%   
  dplyr::select(iso3, cell5m, name_adm1, G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT, treenut_pd, rest_pd) %>%
  dplyr::group_by(iso3, name_adm1, cell5m) %>% 
  dplyr::summarise(round(across(.cols = c(treenut_pd, rest_pd), .fns = sum),1))
  
  # Harvested area 
harv.tib.adm1 = treenut_ha %>%  as_tibble() %>% 
  dplyr::select(iso3, cell5m, name_adm1, G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT, treenut_ha, rest_ha) %>%
  dplyr::group_by(iso3, name_adm1, cell5m) %>% 
  dplyr::summarise(round(across(.cols = c(treenut_ha, rest_ha), .fns = sum),1))  #rounding is kept as in SPAM2010; 1 decimal!

# Join harvested area and calcluate tree nuts ratio  --------------------------
# Validation: Calulation of tnuts ratio correct! 
TnutsRatio_ha_pd_GGS = prod.tib.adm1 %>%
  group_by(iso3, name_adm1) %>% 
  left_join(., harv.tib.adm1, by="cell5m") %>% 
  rowwise() %>% 
  mutate(tnuts_ratio_pd = treenut_pd/(treenut_pd + rest_pd),
         tnuts_ratio_ha = treenut_ha/(treenut_ha + rest_ha)) %>%
  mutate_at(vars(tnuts_ratio_ha, tnuts_ratio_pd), ~replace(., is.nan(.), 0)) %>% 
  dplyr::rename(iso3 = iso3.x, name_adm1 = name_adm1.x) %>%
  dplyr::select(iso3, name_adm1, cell5m, tnuts_ratio_pd, tnuts_ratio_ha)

# write and read treenuts data ----------------------------------------------
write_csv(TnutsRatio_ha_pd_GGS, here::here("Input_data", "ratio_tnuts_ha_pd.csv"))
TnutsRatio_ha_pd_GGS= read_csv(here::here("Input_data", "ratio_tnuts_ha_pd.csv"))#,locale = locale(encoding = "WINDOWS-1252"))

# VEGGIES DISAGGREGATION  -------------------------------------------------
# Loading veggie raster files  ------------------------------------------------
# # Functions Veggies
# load_list_raster <- function(path, type) {
#   pattern <- switch (type,
#                      "yield" = "_YieldPerHectare\\.tif",
#                      "area" = "_HarvestedAreaHectares\\.tif",
#                      "prod" = "_Production\\.tif")
#   path <- list.files(path = path,
#                      full.names = TRUE,
#                      pattern = pattern)
#   l_raster <- lapply(path, raster::raster)
#   # crop_names <- stringr::str_extract(basename(path), "^.+(?=_)")
#   # names(l_raster) <- crop_names
#   return(l_raster)
# }
# # 
# # Exctracting veggies and rest area and production value per adm1 zones
# FunZone_sum=function(rast){ # raster and vector
#   c=zonal.stats(ADM1_SPAM_GGS, rast, stats = c("sum"))
#   c$name_adm1 <- ADM1_SPAM_GGS$name_adm1  # assigning the identifier of the original df to the extracted df
#   dat <- left_join(ADM1_SPAM_GGS, c, by = 'name_adm1') # merge the two files together
# }
# 
# FUN_select_values = function(DF_list){
#   dplyr::select(DF_list, starts_with("sum")) %>% as_tibble() %>%
#     dplyr::select(-geometry)
# }

# Create factors based on other factors conditionally
FunFactCond_veg = function(df, match_vec){
  df %>% mutate(first_tx = ifelse(name %in% match_green, "dark_green", 
                                  ifelse(name %in% match_red, "red_yellow", "other_veg")))
}

# Load treenut data -------------------------------------------------------
# Load harvested area and production raster data
rast_harv_veg = load_list_raster(path=here::here("Input_data", "Veggies_all"), type = "area")
rast_prod_veg = load_list_raster(path=here::here("Input_data", "Veggies_all"), type = "prod")

# Zonal statistics Treenuts -----------------------------------------------
lst_ex_pd_veg = lapply(rast_prod_veg, FunZone_sum)
lst_ex_ha_veg = lapply(rast_harv_veg, FunZone_sum)

# Select the extraction value columns
lst_values_pd_veg = lapply(lst_ex_pd_veg, FUN_select_values)
lst_values_ha_veg = lapply(lst_ex_ha_veg, FUN_select_values)

# Merging all lists together to a df
dat_ex_pd_veg = do.call("cbind", lst_values_pd_veg) # merging all tech types
dat_ex_ha_veg = do.call("cbind", lst_values_ha_veg)

# production values tnuts adm1 --------------------------
veggie_pd = lst_ex_pd_veg[[2]] %>% as_tibble() %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT, geometry) %>% 
  bind_cols(., dat_ex_pd_veg) %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, 
                CONTINENT, matches("^sum\\..+_Production$"), geometry) %>%   
  group_by(iso3, name_adm1) %>% 
  mutate(dark_green_pd = sum(sum.spinach_Production,   
                             sum.vetch_Production)) %>%
  mutate(red_yellow_pd = sum(sum.tomato_Production,
                             sum.pumpkinetc_Production,
                             sum.carrot_Production)) %>% 
  mutate(other_veg_pd = sum(sum.artichoke_Production,
                            sum.asparagus_Production,
                            sum.cabbage_Production,
                            sum.carob_Production,
                            sum.cauliflower_Production,
                            sum.chicory_Production,
                            sum.cucumberetc_Production,
                            sum.eggplant_Production,
                            sum.garlic_Production,
                            sum.greenbean_Production, 
                            sum.greenbroadbean_Production,
                            sum.greencorn_Production,
                            sum.greenonion_Production,
                            sum.greenpea_Production,
                            sum.legumenes_Production,
                            sum.lettuce_Production,
                            sum.mushroom_Production,
                            # sum.olive_Production,
                            sum.onion_Production,
                            sum.stringbean_Production,
                            sum.vegetablenes_Production)) %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT,
                dark_green_pd, red_yellow_pd, other_veg_pd)



# validation of veggie aggregation  ---------------------------------------
# vector containing all three veggie class names 
# veg_dark_vec = c("sum.spinach_Production","sum.vetch_Production")
# veg_red_vec = c("sum.tomato_Production","sum.pumpkinetc_Production",
#                 "sum.carrot_Production")
# veg_other_vec = c("sum.artichoke_Production","sum.asparagus_Production",
#                   "sum.cabbage_Production","sum.carob_Production",
#                   "sum.cauliflower_Production","sum.chicory_Production",
#                   "sum.cucumberetc_Production","sum.eggplant_Production",
#                   "sum.garlic_Production","sum.greenbean_Production", 
#                   "sum.greenbroadbean_Production","sum.greencorn_Production",
#                   "sum.greenonion_Production","sum.greenpea_Production",
#                   "sum.legumenes_Production","sum.lettuce_Production",
#                   "sum.mushroom_Production",# sum.olive_Production,
#                   "sum.onion_Production","sum.stringbean_Production",
#                   "sum.vegetablenes_Production")
# 
# Validate_agg = veggies_pd %>%dplyr::select(tnuts_vec, iso3, name_adm1) %>% 
#   pivot_longer(cols = starts_with("sum."),
#                names_to = "veggies", 
#                values_to = "value")

# calculating the harvested area values for veggies --------------------------
veggie_ha = lst_ex_ha_veg[[2]] %>% as_tibble() %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT, geometry) %>% 
  bind_cols(., dat_ex_ha_veg) %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, 
                CONTINENT, matches("^sum\\..+_HarvestedAreaHectares$"), geometry) %>%   
  group_by(iso3, name_adm1) %>% 
  mutate(dark_green_ha = sum(sum.spinach_HarvestedAreaHectares,   
                             sum.vetch_HarvestedAreaHectares)) %>%
  mutate(red_yellow_ha = sum(sum.tomato_HarvestedAreaHectares,
                             sum.pumpkinetc_HarvestedAreaHectares,
                             sum.carrot_HarvestedAreaHectares)) %>% 
  mutate(other_veg_ha = sum(sum.artichoke_HarvestedAreaHectares,
                            sum.asparagus_HarvestedAreaHectares,
                            sum.cabbage_HarvestedAreaHectares,
                            sum.carob_HarvestedAreaHectares,
                            sum.cauliflower_HarvestedAreaHectares,
                            sum.chicory_HarvestedAreaHectares,
                            sum.cucumberetc_HarvestedAreaHectares,
                            sum.eggplant_HarvestedAreaHectares,
                            sum.garlic_HarvestedAreaHectares,
                            sum.greenbean_HarvestedAreaHectares, 
                            sum.greenbroadbean_HarvestedAreaHectares,
                            sum.greencorn_HarvestedAreaHectares,
                            sum.greenonion_HarvestedAreaHectares,
                            sum.greenpea_HarvestedAreaHectares,
                            sum.legumenes_HarvestedAreaHectares,
                            sum.lettuce_HarvestedAreaHectares,
                            sum.mushroom_HarvestedAreaHectares,
                            # sum.olive_HarvestedAreaHectares,
                            sum.onion_HarvestedAreaHectares,
                            sum.stringbean_HarvestedAreaHectares,
                            sum.vegetablenes_HarvestedAreaHectares)) %>% 
  dplyr::select(iso3, cell5m , name_adm1 , G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT,
                dark_green_ha, red_yellow_ha, other_veg_ha)


# write and read veggie geo data -------------------------------------------
# st_write(veggie_pd, here::here("Input_data", "Core_data",  "GSS_veggie_pd.shp"),
#          driver = "ESRI Shapefile", options = "ENCODING=UTF-8")
# st_write(veggie_ha, here::here("Input_data", "Core_data",  "GSS_veggie_ha.shp"),
#          driver = "ESRI Shapefile", options = "ENCODING=UTF-8")
# #
# veggie_ha = read_sf(here::here("Input_data", "GSS_veggie_pd.shp"), options = "ENCODING=WINDOWS-1252")
# veggie_pd = read_sf(here::here("Input_data", "GSS_veggie_ha.shp"), options = "ENCODING=WINDOWS-1252")

# # Converting to tibble
# sph.prod.tib = treenut_pd %>% as_tibble()
# sph.harv.tib = treenut_ha %>% as_tibble()


# Loading Shapefile GGS ---------------------------------------------------
# ADM1_SPAM_GGS = st_read(here::here("Input_data", "Core_data",  "ADM1_SPAM2010_GGS_geo.shp"), 
#                         options = "ENCODING=WINDOWS-1252")
# ADM1_SPAM_GGS_tib = ADM1_SPAM_GGS %>% as_tibble()

# Loading vegetable files -------------------------------------------------
# veggie_ha = read_sf(here::here("Input_data", "GSS_veggie_pd.shp"), options = "ENCODING=WINDOWS-1252")
# veggie_pd = read_sf(here::here("Input_data", "GSS_veggie_ha.shp"), options = "ENCODING=WINDOWS-1252")
  # # Converting to tibble
  # sph.prod.veg.tib = veggie_pd %>% as_tibble()
  # sph.harv.veg.tib = veggie_ha %>% as_tibble()
  
  # Loading Shapefile GGS
  ADM1_SPAM_GGS = st_read(here::here("Input_data", "Core_data",  "ADM1_SPAM2010_GGS_geo.shp"), options = "ENCODING=WINDOWS-1252")
  ADM1_SPAM_GGS_tib = ADM1_SPAM_GGS %>% as_tibble()
  
  
# Aggregate veggiesto to adm1 unit ---------------------------------------
# Production
  prod.tib.veg.adm1 = veggie_pd %>% as_tibble() %>%   
    dplyr::select(iso3, cell5m, name_adm1, G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT, dark_green_pd, red_yellow_pd,other_veg_pd) %>%
    dplyr::group_by(iso3, name_adm1, cell5m) %>% 
    dplyr::summarise(round(across(.cols = c(dark_green_pd, red_yellow_pd,other_veg_pd), .fns = sum),1))
  
  # Harvested area 
  harv.tib.veg.adm1 = veggie_ha %>%  as_tibble() %>% 
    dplyr::select(iso3, cell5m, name_adm1, G2008_1_ ,ADM0_CODE, ADM1_CODE, CONTINENT, dark_green_ha, red_yellow_ha,other_veg_ha) %>%
    dplyr::group_by(iso3, name_adm1, cell5m) %>% 
    dplyr::summarise(round(across(.cols = c(dark_green_ha, red_yellow_ha,other_veg_ha), .fns = sum),1))  #rounding is kept as in SPAM2010; 1 decimal!
  
  
  # Join harvested area and calcluate veggie ratio  --------------------------
  # Validation: Calulation of veggies ratio correct! adds up to 1. 
ratio_veg_ha_pd = prod.tib.veg.adm1 %>%
    group_by(iso3, name_adm1) %>% 
    left_join(., harv.tib.veg.adm1, by="cell5m") %>% 
    rowwise() %>% 
    mutate(DarkGreen_ratio_pd = dark_green_pd/(dark_green_pd+red_yellow_pd+other_veg_pd),
           DarkGreen_ratio_ha= dark_green_ha/(dark_green_ha+red_yellow_ha+other_veg_ha),
           RedYellow_ratio_pd= red_yellow_pd/(dark_green_pd+red_yellow_pd+other_veg_pd),
           RedYellow_ratio_ha= red_yellow_ha/(dark_green_ha+red_yellow_ha+other_veg_ha),
           OtherVeg_ratio_pd= other_veg_pd/(dark_green_pd+red_yellow_pd+other_veg_pd),
           OtherVeg_ratio_ha= other_veg_ha/(dark_green_ha+red_yellow_ha+other_veg_ha)) %>% 
    mutate_at(vars(DarkGreen_ratio_pd, DarkGreen_ratio_ha, 
                   RedYellow_ratio_pd, RedYellow_ratio_ha,
                   OtherVeg_ratio_pd, OtherVeg_ratio_ha), ~replace(., is.nan(.), 0)) %>% 
    rename(iso3 = iso3.x,
           name_adm1 = name_adm1.x) %>% 
    dplyr::select(cell5m, name_adm1, iso3, DarkGreen_ratio_pd, DarkGreen_ratio_ha, RedYellow_ratio_pd, 
                  RedYellow_ratio_ha, OtherVeg_ratio_pd, OtherVeg_ratio_ha)

# write and read veggie data ----------------------------------------------
write_csv(ratio_veg_ha_pd, here::here("Input_data", "ratio_veg_ha_pd.csv"))
ratio_veg_ha_pd = read_csv(here::here("Input_data", "ratio_veg_ha_pd.csv"))



# Load SPAM single SPAM files (uses less RAM for pulling through t --------


# Production
dat_TA_pr <- read_csv("spam2010V2r0_global_P_TA.csv",locale = locale(encoding = "WINDOWS-1252")) # LATIN2 encoding is used for proper display of nordic and slavic names
dat_TI_pr <- read_csv("spam2010V2r0_global_P_TI.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TH_pr <- read_csv("spam2010V2r0_global_P_TH.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TL_pr <- read_csv("spam2010V2r0_global_P_TL.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TS_pr <- read_csv("spam2010V2r0_global_P_TS.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TR_pr <- read_csv("spam2010V2r0_global_P_TR.csv",locale = locale(encoding = "WINDOWS-1252"))


# Physical area--------------------------------
dat_TA_pa <- read_csv("spam2010V2r0_global_A_TA.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TI_pa <- read_csv("spam2010V2r0_global_A_TI.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TH_pa <- read_csv("spam2010V2r0_global_A_TH.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TL_pa <- read_csv("spam2010V2r0_global_A_TL.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TS_pa <- read_csv("spam2010V2r0_global_A_TS.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TR_pa <- read_csv("spam2010V2r0_global_A_TR.csv",locale = locale(encoding = "WINDOWS-1252"))

# Harvesting area----------------------------------
dat_TA_ha <- read_csv("spam2010V2r0_global_H_TA.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TI_ha <- read_csv("spam2010V2r0_global_H_TI.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TH_ha <- read_csv("spam2010V2r0_global_H_TH.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TL_ha <- read_csv("spam2010V2r0_global_H_TL.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TS_ha <- read_csv("spam2010V2r0_global_H_TS.csv",locale = locale(encoding = "WINDOWS-1252"))
dat_TR_ha <- read_csv("spam2010V2r0_global_H_TR.csv",locale = locale(encoding = "WINDOWS-1252"))

#Aggregating SPAM to Adm1 level  -----------------------------------------------------
ChangeNames <- function(x) { ## Renaming function
  crp <- c('whea', 'rice', 'maiz', 'barl', 'pmil', 'smil', 'sorg', 'ocer', 'pota', 'swpo', 'yams', 'cass', 'orts', 'bean', 'chic', 'cowp', 'pige', 'lent', 'opul', 'soyb',
           'grou', 'cnut', 'oilp', 'sunf', 'rape', 'sesa', 'ooil', 'sugc', 'sugb', 'cott', 'ofib', 'acof', 'rcof', 'coco', 'teas', 'toba', 'bana', 'plnt', 'trof', 'temf', 'vege', 'rest')
  names(x)[10:51] <- crp
  return(x)
} 


TnutsFun_prod = function(spam){
  TnutsRatio_ha_pd_GGS %>%
    group_by(name_adm1, iso3) %>%
    right_join(., spam, by=c("iso3", "name_adm1")) %>%
    mutate(tnuts = rest*tnuts_ratio_pd, 
           rest = rest*(1-tnuts_ratio_pd)) %>%
    relocate(tnuts, .before = rest)
}

TnutsFun_area = function(spam){
  TnutsRatio_ha_pd_GGS %>%
    group_by(name_adm1, iso3) %>% 
    right_join(., spam, by=c("iso3", "name_adm1")) %>%
    mutate(tnuts = rest*tnuts_ratio_ha, 
           rest = rest*(1-tnuts_ratio_ha))%>%
    relocate(tnuts, .before = rest)
}

VeggieFun_prod = function(spam){
  ratio_veg_ha_pd %>%
    group_by(name_adm1, iso3) %>% 
    right_join(., spam, by=c("iso3", "name_adm1")) %>%
    mutate(GreenVeg = vege * DarkGreen_ratio_pd, 
           RedYelVeg = vege * RedYellow_ratio_pd, 
           RestVeg = vege*OtherVeg_ratio_pd) %>%
    relocate(GreenVeg, .before = rest) %>% 
    relocate(RedYelVeg, .before = rest) %>% 
    relocate(RestVeg, .before = rest) %>% 
    dplyr::select(-vege)
}


VeggieFun_area = function(spam){
  ratio_veg_ha_pd %>%
    group_by(name_adm1, iso3) %>% 
    right_join(., spam, by=c("iso3", "name_adm1")) %>%
    mutate(GreenVeg = vege * DarkGreen_ratio_ha, 
           RedYelVeg = vege * RedYellow_ratio_ha, 
           RestVeg = vege*OtherVeg_ratio_ha) %>%
    relocate(GreenVeg, .before = rest) %>% 
  relocate(RedYelVeg, .before = rest) %>% 
  relocate(RestVeg, .before = rest) %>% 
    dplyr::select(-vege)
}


GatherFun <- function(k){
  # k %>% pivot_longer('crop', 'valu', whea:rest)
  k %>% pivot_longer(names_to = "crop", values_to = "valu", cols = whea:rest)
}

# AggregateFun_mean <- function(z){ #for yield
#   ddply(z, .(name_adm1, crop),
#         function(z) mean(z$valu[z$valu!=0]))
# }

# AggregateFun_sum <- function(g){ #for area
#   ddply(g, .(name_adm1, crop),
#         function(g) sum(g$valu))
# }

# This function collapses adm1 units that are in SPAM but not in the GGS administrative unit file
# By combining those adm1 units, the total amount of land per country is expected to match again. 
# If we would have just left those adm1 units away, we would underestimate the area of arable land. 

Adm1MergeSPAM_GSSFUN <- function(u){
 u %>% group_by(name_adm1, iso3) %>% 
    mutate_at(c("name_adm1"), funs(recode(.,'North East (UK)'  = 'East Midlands (UK)',
                             'North West (UK)'  = 'East Midlands (UK)',
                             'Yorkshire and The Humber'  = 'East Midlands (UK)',
                             'West Midlands (UK)'  = 'East Midlands (UK)',
                             'East of England'  = 'East Midlands (UK)',
                             'South East (UK)'  = 'East Midlands (UK)',
                             'South West (UK)'  = 'East Midlands (UK)',
                             'London'  = 'East Midlands (UK)',
                             'Strední Morava' = 'Strední Cechy',
                             'Kriva Palanka'  = 'Kumanova',
                             'Nor Oriental'  = 'Gracias A Dios',
                             'Nororiente'  = 'Sucumbios',
                             'Mzuzu'  = 'Karonga',
                             'Salima'  = 'Kasungu',
                             'Lilongwe'  = 'Kasungu',
                             'Blantyre'  = 'Machinga',
                             'Shire valley'  = 'Machinga')))
}
# 
AggregateFun_sum <- function(g){ #for area
  g %>%  
  dplyr::select(iso3, name_adm1, cell5m.x, rec_type, tech_type, crop, unit, valu) %>%
  dplyr::group_by(iso3, name_adm1, crop, rec_type, tech_type, unit) %>% 
    dplyr::summarise(round(across(valu, sum),1))  #roundin is kept as in SPAM2010; 1 decimal!
}

cell5mFUN <- function(disagSPAM,aggADM1SPAM){ # getting a numeric identifier cell5m for adm1 units. 
  disagSPAM %>% dplyr::distinct_at(vars('name_adm1', 'iso3'), .keep_all = TRUE) %>% 
    dplyr::select(cell5m, iso3, name_adm1) %>% 
    group_by(iso3,name_adm1) %>% 
    right_join(.,aggADM1SPAM, by="name_adm1")
}


CleanFun <- function(l){
l %>% dplyr::select(-iso3.y) %>%  
    dplyr::rename(iso3=iso3.x) %>% 
    dplyr::select(iso3, cell5m, name_adm1, rec_type, tech_type, crop, unit, valu)
}

# Production
TransformFun_prod <- function(d){
  p <- ChangeNames(d)
  u <- Adm1MergeSPAM_GSSFUN(p)
  h <- TnutsFun_prod(u)
  o <- VeggieFun_prod(h)
  l <- GatherFun(o)
  r <- AggregateFun_sum(l)
  y <- cell5mFUN(z,r)
  j <- CleanFun(y)
}

TransformFun_area <- function(d){
p <- ChangeNames(d)
u <- Adm1MergeSPAM_GSSFUN(p)
b <- TnutsFun_area(u)
z <- VeggieFun_area(b)
l <- GatherFun(z)
r <- AggregateFun_sum(l)
y <- cell5mFUN(z,r)
q <- CleanFun(y)
}

# Applying transformation to production
TA_prd <- TransformFun_prod(dat_TA_pr)
TH_prd <- TransformFun_prod(dat_TH_pr)
TI_prd <- TransformFun_prod(dat_TI_pr)
TL_prd <- TransformFun_prod(dat_TL_pr)
TR_prd <- TransformFun_prod(dat_TR_pr)
TS_prd <- TransformFun_prod(dat_TS_pr)
lst.prd <- list(TA_prd, TH_prd, TI_prd, TL_prd, TR_prd, TS_prd)
dat_prd_prod <- do.call("rbind", lst.prd) # merging all tech types
# write_csv(dat_prd, here::here("Input_data", "Core_data", "production_all_rec_tech_adm1.csv")) #careful with encoding when writing and reading files.

#Applying transformation to physical_tech types
TA_phy <- TransformFun_prod(dat_TA_pa)
TH_phy <- TransformFun_prod(dat_TH_pa)
TI_phy <- TransformFun_prod(dat_TI_pa)
TL_phy <- TransformFun_prod(dat_TL_pa)
TR_phy <- TransformFun_prod(dat_TR_pa)
TS_phy <- TransformFun_prod(dat_TS_pa)
lst.phy <- list(TA_phy, TH_phy, TI_phy, TL_phy, TR_phy, TS_phy)
dat_phy_prod <- do.call("rbind", lst.phy) # merging all tech types
# write_csv(dat_phy, here::here("Input_data", "Core_data", "physicalarea_all_rec_tech_adm1.csv")) #careful with encoding when writing and reading files.

#Applying transformation to harvest area types
TA_har <- TransformFun_prod(dat_TA_ha)
TH_har <- TransformFun_prod(dat_TH_ha)
TI_har <- TransformFun_prod(dat_TI_ha)
TL_har <- TransformFun_prod(dat_TL_ha)
TR_har <- TransformFun_prod(dat_TR_ha)
TS_har <- TransformFun_prod(dat_TS_ha)
lst.har <- list(TA_har, TH_har, TI_har, TL_har, TR_har, TS_har)
dat_har_prod <- do.call("rbind", lst.har) # merging all tech types
# write_csv(dat_har, here::here("Input_data", "Core_data", "harvestedarea_all_rec_tech_adm1.csv"))#careful with encoding when writing and reading files.

# Validating aggregation  -------------------------------------------------
# 1. Sum up adm1 units and compare if you get same aggregation results  
# 2. Do this for all rec and tech types 
# dat_har %>%  as_tibble()
# dat_phy %>%  as_tibble()
# dat_prd %>%  as_tibble()


# Independent -- Merging treenuts with SPAM -------------------------------
# prd_dat <- read_csv(here::here("Input_data", "Core_data", "production_all_rec_tech_adm1.csv"))#, locale = locale(encoding = "LATIN2"))
# phy_dat <- read_csv(here::here("Input_data", "Core_data", "physicalarea_all_rec_tech_adm1.csv"))#, locale = locale(encoding = "LATIN2"))
# har_dat <- read_csv(here::here("Input_data", "Core_data", "harvestedarea_all_rec_tech_adm1.csv"))#, locale = locale(encoding = "LATIN2"))

# Final global transformed SPAM2010 dataset. This df is in lign with GGS adm1 units.
SPAM_GGS_all = rbind(dat_prd_area, dat_har_area, dat_phy_area)

# Changing format and calculating yields
dat_spam_global = SPAM_GGS_all %>%
  pivot_wider(!unit,
              names_from = "rec_type", 
              values_from = "valu",#,
              values_fn = mean) %>% 
  rowwise() %>% 
  mutate(Y = round((P*1000/H),1))%>% #checked for result. We are transforming mt to kg  when multiplying Production by 1000 to get unit kg/ha for yields
  mutate_at(vars(Y), ~replace(., is.nan(.), 0)) %>% 
  mutate(P = ifelse(is.infinite(Y), 0, P)) %>% #If Yields show inf values P is changed to 0.
  mutate(Y = ifelse(is.infinite(Y),0, Y)) %>%   #inf values in Y column are changed to 0's
  mutate_at(7:8, round, 1) #H and A had rounding errors. 
write.csv(dat_spam_global, here::here("Input_data", "Core_data", "SPAM_GGS_all_global_recspread_area_ratio.csv")) #Final global dataset aggregated to adm1 level and disaggregating tnuts and three veggies
dat_spam_global = read.csv(here::here("Input_data", "Core_data", "SPAM_GGS_all_global_recspread_area_ratio.csv")) %>%  as_tibble()

# Subsetting EU28 -----------------------------------------------------------

# EU28 --------------------------------------------------------------------
EU_iso3 = c("AUT","BEL", "BGR", "HRV", "CZE", "DNK", "EST","FIN", "FRA", "DEU", "GRC", "HUN", "IRL", "ITA","LVA", 
            "LTU", "LUX", "MLT", "NLD", "POL", "PRT","ROU", "SVK","SVN", "ESP", "SWE", "GBR", "CYP")

EU_cntr_Cifos = c("Austria","Belgium","Bulgaria","Croatia","Cyprus", "Czechia","Denmark",
                  "Estonia","Finland","France","Germany","Greece","Hungary","Ireland",
                  "Italy","Latvia","Lithuania","Luxembourg","Malta","Netherlands","Poland",
                  "Portugal","Romania","Slovakia","Slovenia","Spain","Sweden",'United Kingdom')

# Exporting countries from different file sources 
# CIFOS countries 
# Loading the data with SPAM, CIFOS, GAUL2015, FAO countries 
dat_map_SPAM_GAUL_CIFOS_FAO = read.csv(here("Input_data", "Mappings", "dat_map_SPAM_GAUL_CIFOS_FAO.csv")) %>%  as_tibble()
dat_map_SPAM_GAUL_CIFOS_FAO_full = dat_map_SPAM_GAUL_CIFOS_FAO %>% 
  dplyr::select(-M49_Code, -iso2_code_FAO, -iso3_code_FAO) %>% left_join(., FAOSTAT_cntr, by = c("name_cntr_FAO" = "Country")) 
# SUbsetting crop variables for EU28
cntr_FAO_EU28 = dat_map_SPAM_GAUL_CIFOS_FAO_full %>% filter(., iso3_SPAM  %in% EU_iso3) %>% 
  dplyr::select(iso3_SPAM, me_cntr_CIFOS2021)

# # Getting full CIFOS country names 
# dat_countryEU28 <- read_excel(here("Input_data", "DataValidationFinal.xlsx"), 
#                                   sheet = "Sheet1") %>% 
#     dplyr::select(iso3, Country) %>% distinct_at(vars(iso3, Country))

# dat_crop_info <- read_excel(here("Input_data", "DataValidationFinal.xlsx"),
#                           sheet = "Sheet1") %>%
#   rename(crop=crop_SPAM) %>%
#   group_by(iso3, crop) %>%
#   distinct_at(vars(crop, iso3, Country, crop_SPAM_long, FAO_no, crop_FAO))

SPAM2010_CropList = read_excel("Input_data/SPAM2010_CropList.xlsx", 
                               sheet = "SPAM2010_FAO_agg_pattern") %>%  drop_na() 


# SUBSETTING FOR EU-28 GGS  ----------------------------------------------------------------------
EU_iso3 = c("AUT","BEL", "BGR", "HRV", "CZE", "DNK", "EST","FIN", "FRA", "DEU", "GRC", "HUN", "IRL", "ITA","LVA", 
            "LTU", "LUX", "MLT", "NLD", "POL", "PRT","ROU", "SVK","SVN", "ESP", "SWE", "GBR", "CYP")


# write.csv(EU_iso3, here("Input_data", "EU27_iso3_lst.csv"))
# length(EU_iso3) #27 member states > the list comes from gams

# EU_iso3 %in% dat.phys$iso3 #Validation if all EU27 countries are in the dfs below
dat.SPAM.EU28 = dat_spam_global %>% 
  filter(iso3 %in% EU_iso3) %>% 
  filter(tech_type == "A") %>% 
  dplyr::group_by(iso3, crop) %>%
  dplyr::summarise(round(across(c(P,H,A), sum),1)) %>%   #roundin is kept as in SPAM2010; 1 decimal
  left_join(., crops_FAO_EU28, by = c("iso3" = "iso3_SPAM")) %>%
  dplyr::select(iso3, crop, P:A) %>%
  rename(HarvestedArea_ha = H,
         PhysicalArea_ha = A, 
         Production_mt = P) %>% 
         # crop = crop) %>% 
  mutate(Yield_kgha = round((Production_mt*1000/HarvestedArea_ha),1))%>% #checked for result. We are transforming mt to kg  when multiplying Production by 1000 to get unit kg/ha for yields
  mutate_at(vars(Yield_kgha), ~replace(., is.nan(.), 0)) %>% 
  mutate(Production_mt = ifelse(is.infinite(Yield_kgha), 0, Production_mt)) %>% #If Yields show inf values P is changed to 0.
  mutate(Yield_kgha = ifelse(is.infinite(Yield_kgha),0, Yield_kgha)) %>%   #inf values in Y column are changed to 0's
  mutate(across(c(HarvestedArea_ha,PhysicalArea_ha,Production_mt,Yield_kgha), round, 1)) %>% 
  left_join(., SPAM2010_CropList, by = c("crop" = "short_spam2010")) %>%
  left_join(., cntr_FAO_EU28, by = c("iso3" = "iso3_SPAM")) %>% 
  rename("country_cifos" = "me_cntr_CIFOS2021",
         "crops_cifos" = "cifos_crops",
         "crops_spam" = "crop",
         "crops_fao" = "name_fao") %>% 
  dplyr::select(country_cifos, iso3, crops_cifos, crops_spam, HarvestedArea_ha, PhysicalArea_ha, Production_mt, Yield_kgha) 

# preparing the validation data structure
dat.SPAM.EU_dist = distinct_at(dat.SPAM.EU, vars(iso3, crops_spam), .keep_all = T) %>%
  mutate_at(vars(crops_cifos), funs(ifelse(crops_spam == "GreenVeg", "Spinach", .))) %>% 
  mutate_at(vars(crops_cifos), funs(ifelse(crops_spam == "RedYelVeg", "Carrots", .))) %>% 
  mutate_at(vars(crops_cifos), funs(ifelse(crops_spam == "RestVeg", "Cabbages", .))) %>% 
  mutate_at(vars(crops_cifos), funs(ifelse(crops_spam == "ocer", "Mixed grain", .))) %>% 
  mutate_at(vars(crops_cifos), funs(ifelse(crops_spam == "ofib", "Flax fiber and tow", .))) %>% 
  mutate_at(vars(crops_cifos), funs(ifelse(crops_spam == "orts", "Yautia", .))) %>% 
  mutate_at(vars(crops_cifos), funs(ifelse(crops_spam == "ooil", "Olives", .))) %>% 
  mutate_at(vars(crops_cifos), funs(ifelse(crops_spam == "rest", "Chilies and peppers, green", .))) %>% 
  mutate_at(vars(crops_cifos), funs(ifelse(crops_spam == "trof", "Oranges", .))) %>% 
  mutate_at(vars(crops_cifos), funs(ifelse(crops_spam == "temf", "Apples", .))) %>% 
  mutate_at(vars(crops_cifos), funs(ifelse(crops_spam == "tnuts", "Walnuts", .)))
                                    

    
write.csv(dat.SPAM.EU_dist, here::here("Input_data", "Core_data", "SPAM_Crops_EU28_alltecRec_nuts_veg.csv"))#, 
          # locale = locale(encoding = "LATIN2"))

# Subsetting GGS ----------------------------------------------------------


# Ratio harvest and physical area  ----------------------------------------
global_tab_spam = dat_spam_global = read.csv(here::here("Input_data", "Core_data", "SPAM_GGS_all_global_recspread_area_ratio.csv")) %>%  as_tibble()

# Aggregating to country level
cntr_level = global_tab_spam %>%
  mutate(ratio_harv_phys = H/A) %>%
  group_by(iso3) %>% 
  filter(crop != c("tnuts", "rest", "GreenVeg", "RedYelVeg", "RestVeg"),
         ratio_harv_phys >= 1 &
           # ratio_harv_phys <= 5 &
           is.infinite(ratio_harv_phys)  == FALSE) %>%
summarise(mean = mean(ratio_harv_phys),
          max = max(ratio_harv_phys)) %>% 
  arrange(desc(max))

